/* nightlightapplet.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __SRC_PANEL_APPLETS_NIGHT_LIGHT_NIGHTLIGHTAPPLET_H__
#define __SRC_PANEL_APPLETS_NIGHT_LIGHT_NIGHTLIGHTAPPLET_H__

#include <libpeas.h>
#include "plugin.h"
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define NIGHT_LIGHT_TYPE_PLUGIN (night_light_plugin_get_type ())
#define NIGHT_LIGHT_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NIGHT_LIGHT_TYPE_PLUGIN, NightLightPlugin))
#define NIGHT_LIGHT_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NIGHT_LIGHT_TYPE_PLUGIN, NightLightPluginClass))
#define NIGHT_LIGHT_IS_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NIGHT_LIGHT_TYPE_PLUGIN))
#define NIGHT_LIGHT_IS_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NIGHT_LIGHT_TYPE_PLUGIN))
#define NIGHT_LIGHT_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NIGHT_LIGHT_TYPE_PLUGIN, NightLightPluginClass))

typedef struct _NightLightPlugin NightLightPlugin;
typedef struct _NightLightPluginClass NightLightPluginClass;
typedef struct _NightLightPluginPrivate NightLightPluginPrivate;

#define NIGHT_LIGHT_TYPE_APPLET (night_light_applet_get_type ())
#define NIGHT_LIGHT_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NIGHT_LIGHT_TYPE_APPLET, NightLightApplet))
#define NIGHT_LIGHT_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NIGHT_LIGHT_TYPE_APPLET, NightLightAppletClass))
#define NIGHT_LIGHT_IS_APPLET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NIGHT_LIGHT_TYPE_APPLET))
#define NIGHT_LIGHT_IS_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NIGHT_LIGHT_TYPE_APPLET))
#define NIGHT_LIGHT_APPLET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NIGHT_LIGHT_TYPE_APPLET, NightLightAppletClass))

typedef struct _NightLightApplet NightLightApplet;
typedef struct _NightLightAppletClass NightLightAppletClass;
typedef struct _NightLightAppletPrivate NightLightAppletPrivate;

struct _NightLightPlugin {
	PeasExtensionBase parent_instance;
	NightLightPluginPrivate * priv;
};

struct _NightLightPluginClass {
	PeasExtensionBaseClass parent_class;
};

struct _NightLightApplet {
	BudgieApplet parent_instance;
	NightLightAppletPrivate * priv;
};

struct _NightLightAppletClass {
	BudgieAppletClass parent_class;
};

GType night_light_plugin_register_type (GTypeModule * module);
VALA_EXTERN GType night_light_plugin_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NightLightPlugin, g_object_unref)
VALA_EXTERN NightLightPlugin* night_light_plugin_new (void);
VALA_EXTERN NightLightPlugin* night_light_plugin_construct (GType object_type);
GType night_light_applet_register_type (GTypeModule * module);
VALA_EXTERN GType night_light_applet_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NightLightApplet, g_object_unref)
VALA_EXTERN NightLightApplet* night_light_applet_new (const gchar* uuid);
VALA_EXTERN NightLightApplet* night_light_applet_construct (GType object_type,
                                                const gchar* uuid);
VALA_EXTERN const gchar* night_light_applet_get_uuid (NightLightApplet* self);
VALA_EXTERN void night_light_applet_set_uuid (NightLightApplet* self,
                                  const gchar* value);
VALA_EXTERN void peas_register_types (GTypeModule* module);

G_END_DECLS

#endif
