
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "budgie-enums.h"
/* enumerations from "/build/budgie-desktop/src/build/../budgie-desktop/src/plugin/panel/applet.h" */
GType
budgie_panel_action_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GFlagsValue values[] = {
            { BUDGIE_PANEL_ACTION_NONE, "BUDGIE_PANEL_ACTION_NONE", "none" },
            { BUDGIE_PANEL_ACTION_MENU, "BUDGIE_PANEL_ACTION_MENU", "menu" },
            { BUDGIE_PANEL_ACTION_MAX, "BUDGIE_PANEL_ACTION_MAX", "max" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static (g_intern_static_string ("BudgiePanelAction"), values);
    }
    return etype;
}
GType
budgie_panel_position_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GFlagsValue values[] = {
            { BUDGIE_PANEL_POSITION_NONE, "BUDGIE_PANEL_POSITION_NONE", "none" },
            { BUDGIE_PANEL_POSITION_BOTTOM, "BUDGIE_PANEL_POSITION_BOTTOM", "bottom" },
            { BUDGIE_PANEL_POSITION_TOP, "BUDGIE_PANEL_POSITION_TOP", "top" },
            { BUDGIE_PANEL_POSITION_LEFT, "BUDGIE_PANEL_POSITION_LEFT", "left" },
            { BUDGIE_PANEL_POSITION_RIGHT, "BUDGIE_PANEL_POSITION_RIGHT", "right" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static (g_intern_static_string ("BudgiePanelPosition"), values);
    }
    return etype;
}


/* Generated data ends here */

