/* icontasklistapplet.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __SRC_PANEL_APPLETS_ICON_TASKLIST_ICONTASKLISTAPPLET_H__
#define __SRC_PANEL_APPLETS_ICON_TASKLIST_ICONTASKLISTAPPLET_H__

#include <glib-object.h>
#include <libxfce4windowing/libxfce4windowing.h>
#include "budgie-windowing.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include "budgie-private.h"
#include <gtk/gtk.h>
#include <libpeas.h>
#include "plugin.h"
#include <gio/gio.h>
#include <float.h>
#include <math.h>
#include <cairo-gobject.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define BUDGIE_TYPE_APPLICATION_MATCHER (budgie_application_matcher_get_type ())
#define BUDGIE_APPLICATION_MATCHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BUDGIE_TYPE_APPLICATION_MATCHER, BudgieApplicationMatcher))
#define BUDGIE_APPLICATION_MATCHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BUDGIE_TYPE_APPLICATION_MATCHER, BudgieApplicationMatcherClass))
#define BUDGIE_IS_APPLICATION_MATCHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BUDGIE_TYPE_APPLICATION_MATCHER))
#define BUDGIE_IS_APPLICATION_MATCHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BUDGIE_TYPE_APPLICATION_MATCHER))
#define BUDGIE_APPLICATION_MATCHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BUDGIE_TYPE_APPLICATION_MATCHER, BudgieApplicationMatcherClass))

typedef struct _BudgieApplicationMatcher BudgieApplicationMatcher;
typedef struct _BudgieApplicationMatcherClass BudgieApplicationMatcherClass;
typedef struct _BudgieApplicationMatcherPrivate BudgieApplicationMatcherPrivate;

#define BUDGIE_APPLICATION_MATCHER_TYPE_MATCH_RESULT (budgie_application_matcher_match_result_get_type ())
#define BUDGIE_APPLICATION_MATCHER_MATCH_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BUDGIE_APPLICATION_MATCHER_TYPE_MATCH_RESULT, BudgieApplicationMatcherMatchResult))
#define BUDGIE_APPLICATION_MATCHER_MATCH_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BUDGIE_APPLICATION_MATCHER_TYPE_MATCH_RESULT, BudgieApplicationMatcherMatchResultClass))
#define BUDGIE_APPLICATION_MATCHER_IS_MATCH_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BUDGIE_APPLICATION_MATCHER_TYPE_MATCH_RESULT))
#define BUDGIE_APPLICATION_MATCHER_IS_MATCH_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BUDGIE_APPLICATION_MATCHER_TYPE_MATCH_RESULT))
#define BUDGIE_APPLICATION_MATCHER_MATCH_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BUDGIE_APPLICATION_MATCHER_TYPE_MATCH_RESULT, BudgieApplicationMatcherMatchResultClass))

typedef struct _BudgieApplicationMatcherMatchResult BudgieApplicationMatcherMatchResult;
typedef struct _BudgieApplicationMatcherMatchResultClass BudgieApplicationMatcherMatchResultClass;
typedef struct _BudgieApplicationMatcherMatchResultPrivate BudgieApplicationMatcherMatchResultPrivate;

#define TYPE_ICON_TASKLIST (icon_tasklist_get_type ())
#define ICON_TASKLIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ICON_TASKLIST, IconTasklist))
#define ICON_TASKLIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ICON_TASKLIST, IconTasklistClass))
#define IS_ICON_TASKLIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ICON_TASKLIST))
#define IS_ICON_TASKLIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ICON_TASKLIST))
#define ICON_TASKLIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ICON_TASKLIST, IconTasklistClass))

typedef struct _IconTasklist IconTasklist;
typedef struct _IconTasklistClass IconTasklistClass;
typedef struct _IconTasklistPrivate IconTasklistPrivate;

#define TYPE_ICON_TASKLIST_SETTINGS (icon_tasklist_settings_get_type ())
#define ICON_TASKLIST_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ICON_TASKLIST_SETTINGS, IconTasklistSettings))
#define ICON_TASKLIST_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ICON_TASKLIST_SETTINGS, IconTasklistSettingsClass))
#define IS_ICON_TASKLIST_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ICON_TASKLIST_SETTINGS))
#define IS_ICON_TASKLIST_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ICON_TASKLIST_SETTINGS))
#define ICON_TASKLIST_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ICON_TASKLIST_SETTINGS, IconTasklistSettingsClass))

typedef struct _IconTasklistSettings IconTasklistSettings;
typedef struct _IconTasklistSettingsClass IconTasklistSettingsClass;
typedef struct _IconTasklistSettingsPrivate IconTasklistSettingsPrivate;

#define TYPE_ICON_TASKLIST_APPLET (icon_tasklist_applet_get_type ())
#define ICON_TASKLIST_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ICON_TASKLIST_APPLET, IconTasklistApplet))
#define ICON_TASKLIST_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ICON_TASKLIST_APPLET, IconTasklistAppletClass))
#define IS_ICON_TASKLIST_APPLET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ICON_TASKLIST_APPLET))
#define IS_ICON_TASKLIST_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ICON_TASKLIST_APPLET))
#define ICON_TASKLIST_APPLET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ICON_TASKLIST_APPLET, IconTasklistAppletClass))

typedef struct _IconTasklistApplet IconTasklistApplet;
typedef struct _IconTasklistAppletClass IconTasklistAppletClass;
typedef struct _IconTasklistAppletPrivate IconTasklistAppletPrivate;

#define TYPE_SETTINGS_REMOTE (settings_remote_get_type ())
#define SETTINGS_REMOTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SETTINGS_REMOTE, SettingsRemote))
#define IS_SETTINGS_REMOTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SETTINGS_REMOTE))
#define SETTINGS_REMOTE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_SETTINGS_REMOTE, SettingsRemoteIface))

typedef struct _SettingsRemote SettingsRemote;
typedef struct _SettingsRemoteIface SettingsRemoteIface;

#define TYPE_SETTINGS_REMOTE_PROXY (settings_remote_proxy_get_type ())

#define TYPE_ICON_TASKLIST_BUTTON_POPOVER (icon_tasklist_button_popover_get_type ())
#define ICON_TASKLIST_BUTTON_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ICON_TASKLIST_BUTTON_POPOVER, IconTasklistButtonPopover))
#define ICON_TASKLIST_BUTTON_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ICON_TASKLIST_BUTTON_POPOVER, IconTasklistButtonPopoverClass))
#define IS_ICON_TASKLIST_BUTTON_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ICON_TASKLIST_BUTTON_POPOVER))
#define IS_ICON_TASKLIST_BUTTON_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ICON_TASKLIST_BUTTON_POPOVER))
#define ICON_TASKLIST_BUTTON_POPOVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ICON_TASKLIST_BUTTON_POPOVER, IconTasklistButtonPopoverClass))

typedef struct _IconTasklistButtonPopover IconTasklistButtonPopover;
typedef struct _IconTasklistButtonPopoverClass IconTasklistButtonPopoverClass;
typedef struct _IconTasklistButtonPopoverPrivate IconTasklistButtonPopoverPrivate;

#define TYPE_ICON_BUTTON (icon_button_get_type ())
#define ICON_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ICON_BUTTON, IconButton))
#define ICON_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ICON_BUTTON, IconButtonClass))
#define IS_ICON_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ICON_BUTTON))
#define IS_ICON_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ICON_BUTTON))
#define ICON_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ICON_BUTTON, IconButtonClass))

typedef struct _IconButton IconButton;
typedef struct _IconButtonClass IconButtonClass;

#define TYPE_BUTTON_WRAPPER (button_wrapper_get_type ())
#define BUTTON_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BUTTON_WRAPPER, ButtonWrapper))
#define BUTTON_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BUTTON_WRAPPER, ButtonWrapperClass))
#define IS_BUTTON_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BUTTON_WRAPPER))
#define IS_BUTTON_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BUTTON_WRAPPER))
#define BUTTON_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BUTTON_WRAPPER, ButtonWrapperClass))

typedef struct _ButtonWrapper ButtonWrapper;
typedef struct _ButtonWrapperClass ButtonWrapperClass;
typedef struct _ButtonWrapperPrivate ButtonWrapperPrivate;

#define TYPE_ICON (icon_get_type ())
#define ICON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ICON, Icon))
#define ICON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ICON, IconClass))
#define IS_ICON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ICON))
#define IS_ICON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ICON))
#define ICON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ICON, IconClass))

typedef struct _Icon Icon;
typedef struct _IconClass IconClass;
typedef struct _IconPrivate IconPrivate;
typedef struct _IconButtonPrivate IconButtonPrivate;

struct _BudgieApplicationMatcher {
	GObject parent_instance;
	BudgieApplicationMatcherPrivate * priv;
};

struct _BudgieApplicationMatcherClass {
	GObjectClass parent_class;
};

struct _BudgieApplicationMatcherMatchResult {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BudgieApplicationMatcherMatchResultPrivate * priv;
};

struct _BudgieApplicationMatcherMatchResultClass {
	GTypeClass parent_class;
	void (*finalize) (BudgieApplicationMatcherMatchResult *self);
};

struct _IconTasklist {
	PeasExtensionBase parent_instance;
	IconTasklistPrivate * priv;
};

struct _IconTasklistClass {
	PeasExtensionBaseClass parent_class;
};

struct _IconTasklistSettings {
	GtkGrid parent_instance;
	IconTasklistSettingsPrivate * priv;
};

struct _IconTasklistSettingsClass {
	GtkGridClass parent_class;
};

struct _IconTasklistApplet {
	BudgieApplet parent_instance;
	IconTasklistAppletPrivate * priv;
};

struct _IconTasklistAppletClass {
	BudgieAppletClass parent_class;
};

struct _SettingsRemoteIface {
	GTypeInterface parent_iface;
	void (*Close) (SettingsRemote* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*Close_finish) (SettingsRemote* self, GAsyncResult* _res_, GError** error);
};

struct _IconTasklistButtonPopover {
	GtkPopover parent_instance;
	IconTasklistButtonPopoverPrivate * priv;
};

struct _IconTasklistButtonPopoverClass {
	GtkPopoverClass parent_class;
};

struct _ButtonWrapper {
	GtkRevealer parent_instance;
	ButtonWrapperPrivate * priv;
};

struct _ButtonWrapperClass {
	GtkRevealerClass parent_class;
};

struct _Icon {
	GtkImage parent_instance;
	IconPrivate * priv;
	gboolean waiting;
};

struct _IconClass {
	GtkImageClass parent_class;
};

struct _IconButton {
	GtkToggleButton parent_instance;
	IconButtonPrivate * priv;
};

struct _IconButtonClass {
	GtkToggleButtonClass parent_class;
};

GType budgie_application_matcher_register_type (GTypeModule * module);
VALA_EXTERN GType budgie_application_matcher_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieApplicationMatcher, g_object_unref)
VALA_EXTERN gpointer budgie_application_matcher_match_result_ref (gpointer instance);
VALA_EXTERN void budgie_application_matcher_match_result_unref (gpointer instance);
VALA_EXTERN GParamSpec* budgie_application_matcher_param_spec_match_result (const gchar* name,
                                                                const gchar* nick,
                                                                const gchar* blurb,
                                                                GType object_type,
                                                                GParamFlags flags);
VALA_EXTERN void budgie_application_matcher_value_set_match_result (GValue* value,
                                                        gpointer v_object);
VALA_EXTERN void budgie_application_matcher_value_take_match_result (GValue* value,
                                                         gpointer v_object);
VALA_EXTERN gpointer budgie_application_matcher_value_get_match_result (const GValue* value);
GType budgie_application_matcher_match_result_register_type (GTypeModule * module);
VALA_EXTERN GType budgie_application_matcher_match_result_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieApplicationMatcherMatchResult, budgie_application_matcher_match_result_unref)
VALA_EXTERN BudgieApplicationMatcherMatchResult* budgie_application_matcher_match_window (BudgieApplicationMatcher* self,
                                                                              XfwWindow* window);
VALA_EXTERN BudgieApplicationMatcherMatchResult* budgie_application_matcher_match_window_group (BudgieApplicationMatcher* self,
                                                                                    BudgieWindowingWindowGroup* group);
VALA_EXTERN BudgieApplication* budgie_application_matcher_create_application (BudgieApplicationMatcher* self,
                                                                  const gchar* desktop_id);
VALA_EXTERN BudgieApplicationMatcher* budgie_application_matcher_new (void);
VALA_EXTERN BudgieApplicationMatcher* budgie_application_matcher_construct (GType object_type);
VALA_EXTERN gboolean budgie_application_matcher_match_result_matched (BudgieApplicationMatcherMatchResult* self);
VALA_EXTERN BudgieApplicationMatcherMatchResult* budgie_application_matcher_match_result_new (void);
VALA_EXTERN BudgieApplicationMatcherMatchResult* budgie_application_matcher_match_result_construct (GType object_type);
VALA_EXTERN const gchar* budgie_application_matcher_match_result_get_desktop_id (BudgieApplicationMatcherMatchResult* self);
VALA_EXTERN void budgie_application_matcher_match_result_set_desktop_id (BudgieApplicationMatcherMatchResult* self,
                                                             const gchar* value);
GType icon_tasklist_register_type (GTypeModule * module);
VALA_EXTERN GType icon_tasklist_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (IconTasklist, g_object_unref)
VALA_EXTERN IconTasklist* icon_tasklist_new (void);
VALA_EXTERN IconTasklist* icon_tasklist_construct (GType object_type);
GType icon_tasklist_settings_register_type (GTypeModule * module);
VALA_EXTERN GType icon_tasklist_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (IconTasklistSettings, g_object_unref)
VALA_EXTERN IconTasklistSettings* icon_tasklist_settings_new (GSettings* settings);
VALA_EXTERN IconTasklistSettings* icon_tasklist_settings_construct (GType object_type,
                                                        GSettings* settings);
GType icon_tasklist_applet_register_type (GTypeModule * module);
VALA_EXTERN GType icon_tasklist_applet_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (IconTasklistApplet, g_object_unref)
VALA_EXTERN IconTasklistApplet* icon_tasklist_applet_new (const gchar* uuid);
VALA_EXTERN IconTasklistApplet* icon_tasklist_applet_construct (GType object_type,
                                                    const gchar* uuid);
VALA_EXTERN const gchar* icon_tasklist_applet_get_uuid (IconTasklistApplet* self);
VALA_EXTERN void icon_tasklist_applet_set_uuid (IconTasklistApplet* self,
                                    const gchar* value);
VALA_EXTERN void peas_register_types (GTypeModule* module);
VALA_EXTERN GType settings_remote_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void settings_remote_proxy_register_dynamic_type (GTypeModule* module);
VALA_EXTERN guint settings_remote_register_object (void* object,
                                       GDBusConnection* connection,
                                       const gchar* path,
                                       GError** error);
GType settings_remote_register_type (GTypeModule * module);
VALA_EXTERN GType settings_remote_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SettingsRemote, g_object_unref)
VALA_EXTERN void settings_remote_Close (SettingsRemote* self,
                            GAsyncReadyCallback _callback_,
                            gpointer _user_data_);
VALA_EXTERN void settings_remote_Close_finish (SettingsRemote* self,
                                   GAsyncResult* _res_,
                                   GError** error);
GType icon_tasklist_button_popover_register_type (GTypeModule * module);
VALA_EXTERN GType icon_tasklist_button_popover_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (IconTasklistButtonPopover, g_object_unref)
GType icon_button_register_type (GTypeModule * module);
VALA_EXTERN GType icon_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (IconButton, g_object_unref)
VALA_EXTERN IconTasklistButtonPopover* icon_tasklist_button_popover_new (IconButton* button,
                                                             BudgieApplication* app,
                                                             BudgieWindowingWindowGroup* group);
VALA_EXTERN IconTasklistButtonPopover* icon_tasklist_button_popover_construct (GType object_type,
                                                                   IconButton* button,
                                                                   BudgieApplication* app,
                                                                   BudgieWindowingWindowGroup* group);
VALA_EXTERN void icon_tasklist_button_popover_add_window (IconTasklistButtonPopover* self,
                                              XfwWindow* window);
VALA_EXTERN void icon_tasklist_button_popover_remove_window (IconTasklistButtonPopover* self,
                                                 XfwWindow* window);
VALA_EXTERN BudgieApplication* icon_tasklist_button_popover_get_app (IconTasklistButtonPopover* self);
VALA_EXTERN BudgieWindowingWindowGroup* icon_tasklist_button_popover_get_group (IconTasklistButtonPopover* self);
VALA_EXTERN void icon_tasklist_button_popover_set_group (IconTasklistButtonPopover* self,
                                             BudgieWindowingWindowGroup* value);
VALA_EXTERN gboolean icon_tasklist_button_popover_get_pinned (IconTasklistButtonPopover* self);
VALA_EXTERN void icon_tasklist_button_popover_set_pinned (IconTasklistButtonPopover* self,
                                              gboolean value);
GType button_wrapper_register_type (GTypeModule * module);
VALA_EXTERN GType button_wrapper_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ButtonWrapper, g_object_unref)
VALA_EXTERN ButtonWrapper* button_wrapper_new (IconButton* button);
VALA_EXTERN ButtonWrapper* button_wrapper_construct (GType object_type,
                                         IconButton* button);
VALA_EXTERN void button_wrapper_gracefully_die (ButtonWrapper* self);
VALA_EXTERN IconButton* button_wrapper_get_button (ButtonWrapper* self);
VALA_EXTERN GtkOrientation button_wrapper_get_orient (ButtonWrapper* self);
VALA_EXTERN void button_wrapper_set_orient (ButtonWrapper* self,
                                GtkOrientation value);
GType icon_register_type (GTypeModule * module);
VALA_EXTERN GType icon_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Icon, g_object_unref)
VALA_EXTERN Icon* icon_new (void);
VALA_EXTERN Icon* icon_construct (GType object_type);
VALA_EXTERN void icon_on_size_allocate (Icon* self,
                            GtkAllocation* allocation);
VALA_EXTERN void icon_animate_attention (Icon* self,
                             BudgiePanelPosition* position);
VALA_EXTERN void icon_animate_wait (Icon* self);
VALA_EXTERN void icon_animate_launch (Icon* self,
                          BudgiePanelPosition position);
VALA_EXTERN gdouble icon_get_bounce (Icon* self);
VALA_EXTERN void icon_set_bounce (Icon* self,
                      gdouble value);
VALA_EXTERN gdouble icon_get_attention (Icon* self);
VALA_EXTERN void icon_set_attention (Icon* self,
                         gdouble value);
VALA_EXTERN gdouble icon_get_icon_opacity (Icon* self);
VALA_EXTERN void icon_set_icon_opacity (Icon* self,
                            gdouble value);
VALA_EXTERN IconButton* icon_button_new (BudgiePopoverManager* popover_manager,
                             BudgieApplication* app);
VALA_EXTERN IconButton* icon_button_construct (GType object_type,
                                   BudgiePopoverManager* popover_manager,
                                   BudgieApplication* app);
VALA_EXTERN IconButton* icon_button_new_with_group (BudgieWindowingWindowGroup* window_group,
                                        BudgiePopoverManager* popover_manager,
                                        BudgieApplication* app);
VALA_EXTERN IconButton* icon_button_construct_with_group (GType object_type,
                                              BudgieWindowingWindowGroup* window_group,
                                              BudgiePopoverManager* popover_manager,
                                              BudgieApplication* app);
VALA_EXTERN gboolean icon_button_draw_inactive (IconButton* self,
                                    cairo_t* ctx);
VALA_EXTERN gboolean icon_button_has_window (IconButton* self,
                                 XfwWindow* window);
VALA_EXTERN Icon* icon_button_get_icon (IconButton* self);
VALA_EXTERN gboolean icon_button_launch (IconButton* self);
VALA_EXTERN void icon_button_set_active_window (IconButton* self,
                                    gboolean active);
VALA_EXTERN void icon_button_set_icon_size (IconButton* self,
                                gint size);
VALA_EXTERN void icon_button_set_orientation (IconButton* self,
                                  GtkOrientation orientation);
VALA_EXTERN void icon_button_set_panel_size (IconButton* self,
                                 gint size);
VALA_EXTERN void icon_button_set_panel_position (IconButton* self,
                                     BudgiePanelPosition position);
VALA_EXTERN BudgieWindowingWindowGroup* icon_button_get_window_group (IconButton* self);
VALA_EXTERN void icon_button_set_urgent (IconButton* self,
                             gboolean urgent);
VALA_EXTERN void icon_button_set_window_group (IconButton* self,
                                   BudgieWindowingWindowGroup* window_group);
VALA_EXTERN void icon_button_update (IconButton* self);
VALA_EXTERN void icon_button_update_icon (IconButton* self);
VALA_EXTERN BudgieApplication* icon_button_get_app (IconButton* self);
VALA_EXTERN BudgiePopoverManager* icon_button_get_popover_manager (IconButton* self);
VALA_EXTERN gboolean icon_button_get_pinned (IconButton* self);
VALA_EXTERN void icon_button_set_pinned (IconButton* self,
                             gboolean value);
VALA_EXTERN gboolean icon_button_get_has_active_window (IconButton* self);

VALA_EXTERN const GtkTargetEntry DRAG_TARGETS[2];
VALA_EXTERN const GtkTargetEntry SOURCE_TARGET[1];

G_END_DECLS

#endif
