/* statusapplet.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __SRC_PANEL_APPLETS_STATUS_STATUSAPPLET_H__
#define __SRC_PANEL_APPLETS_STATUS_STATUSAPPLET_H__

#include <libpeas.h>
#include "plugin.h"
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <upower.h>
#include <gdk/gdk.h>
#include <pulse/pulseaudio.h>
#include <gvc-mixer-control.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_STATUS_PLUGIN (status_plugin_get_type ())
#define STATUS_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_STATUS_PLUGIN, StatusPlugin))
#define STATUS_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_STATUS_PLUGIN, StatusPluginClass))
#define IS_STATUS_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_STATUS_PLUGIN))
#define IS_STATUS_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_STATUS_PLUGIN))
#define STATUS_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_STATUS_PLUGIN, StatusPluginClass))

typedef struct _StatusPlugin StatusPlugin;
typedef struct _StatusPluginClass StatusPluginClass;
typedef struct _StatusPluginPrivate StatusPluginPrivate;

#define TYPE_STATUS_SETTINGS (status_settings_get_type ())
#define STATUS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_STATUS_SETTINGS, StatusSettings))
#define STATUS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_STATUS_SETTINGS, StatusSettingsClass))
#define IS_STATUS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_STATUS_SETTINGS))
#define IS_STATUS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_STATUS_SETTINGS))
#define STATUS_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_STATUS_SETTINGS, StatusSettingsClass))

typedef struct _StatusSettings StatusSettings;
typedef struct _StatusSettingsClass StatusSettingsClass;
typedef struct _StatusSettingsPrivate StatusSettingsPrivate;

#define TYPE_STATUS_APPLET (status_applet_get_type ())
#define STATUS_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_STATUS_APPLET, StatusApplet))
#define STATUS_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_STATUS_APPLET, StatusAppletClass))
#define IS_STATUS_APPLET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_STATUS_APPLET))
#define IS_STATUS_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_STATUS_APPLET))
#define STATUS_APPLET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_STATUS_APPLET, StatusAppletClass))

typedef struct _StatusApplet StatusApplet;
typedef struct _StatusAppletClass StatusAppletClass;
typedef struct _StatusAppletPrivate StatusAppletPrivate;

#define TYPE_BLUETOOTH_INDICATOR (bluetooth_indicator_get_type ())
#define BLUETOOTH_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BLUETOOTH_INDICATOR, BluetoothIndicator))
#define BLUETOOTH_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BLUETOOTH_INDICATOR, BluetoothIndicatorClass))
#define IS_BLUETOOTH_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BLUETOOTH_INDICATOR))
#define IS_BLUETOOTH_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BLUETOOTH_INDICATOR))
#define BLUETOOTH_INDICATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BLUETOOTH_INDICATOR, BluetoothIndicatorClass))

typedef struct _BluetoothIndicator BluetoothIndicator;
typedef struct _BluetoothIndicatorClass BluetoothIndicatorClass;

#define TYPE_SOUND_INDICATOR (sound_indicator_get_type ())
#define SOUND_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOUND_INDICATOR, SoundIndicator))
#define SOUND_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOUND_INDICATOR, SoundIndicatorClass))
#define IS_SOUND_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOUND_INDICATOR))
#define IS_SOUND_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOUND_INDICATOR))
#define SOUND_INDICATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOUND_INDICATOR, SoundIndicatorClass))

typedef struct _SoundIndicator SoundIndicator;
typedef struct _SoundIndicatorClass SoundIndicatorClass;

#define TYPE_POWER_INDICATOR (power_indicator_get_type ())
#define POWER_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_POWER_INDICATOR, PowerIndicator))
#define POWER_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_POWER_INDICATOR, PowerIndicatorClass))
#define IS_POWER_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_POWER_INDICATOR))
#define IS_POWER_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_POWER_INDICATOR))
#define POWER_INDICATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_POWER_INDICATOR, PowerIndicatorClass))

typedef struct _PowerIndicator PowerIndicator;
typedef struct _PowerIndicatorClass PowerIndicatorClass;

#define TYPE_BATTERY_ICON (battery_icon_get_type ())
#define BATTERY_ICON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATTERY_ICON, BatteryIcon))
#define BATTERY_ICON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATTERY_ICON, BatteryIconClass))
#define IS_BATTERY_ICON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATTERY_ICON))
#define IS_BATTERY_ICON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATTERY_ICON))
#define BATTERY_ICON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATTERY_ICON, BatteryIconClass))

typedef struct _BatteryIcon BatteryIcon;
typedef struct _BatteryIconClass BatteryIconClass;
typedef struct _BatteryIconPrivate BatteryIconPrivate;

#define TYPE_POWER_PROFILES_DBUS (power_profiles_dbus_get_type ())
#define POWER_PROFILES_DBUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_POWER_PROFILES_DBUS, PowerProfilesDBus))
#define IS_POWER_PROFILES_DBUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_POWER_PROFILES_DBUS))
#define POWER_PROFILES_DBUS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_POWER_PROFILES_DBUS, PowerProfilesDBusIface))

typedef struct _PowerProfilesDBus PowerProfilesDBus;
typedef struct _PowerProfilesDBusIface PowerProfilesDBusIface;

#define TYPE_POWER_PROFILES_DBUS_PROXY (power_profiles_dbus_proxy_get_type ())

#define TYPE_POWER_PROFILES_OPTION (power_profiles_option_get_type ())
#define POWER_PROFILES_OPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_POWER_PROFILES_OPTION, PowerProfilesOption))
#define POWER_PROFILES_OPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_POWER_PROFILES_OPTION, PowerProfilesOptionClass))
#define IS_POWER_PROFILES_OPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_POWER_PROFILES_OPTION))
#define IS_POWER_PROFILES_OPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_POWER_PROFILES_OPTION))
#define POWER_PROFILES_OPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_POWER_PROFILES_OPTION, PowerProfilesOptionClass))

typedef struct _PowerProfilesOption PowerProfilesOption;
typedef struct _PowerProfilesOptionClass PowerProfilesOptionClass;
typedef struct _PowerProfilesOptionPrivate PowerProfilesOptionPrivate;

#define TYPE_POWER_PROFILES_SELECTOR (power_profiles_selector_get_type ())
#define POWER_PROFILES_SELECTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_POWER_PROFILES_SELECTOR, PowerProfilesSelector))
#define POWER_PROFILES_SELECTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_POWER_PROFILES_SELECTOR, PowerProfilesSelectorClass))
#define IS_POWER_PROFILES_SELECTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_POWER_PROFILES_SELECTOR))
#define IS_POWER_PROFILES_SELECTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_POWER_PROFILES_SELECTOR))
#define POWER_PROFILES_SELECTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_POWER_PROFILES_SELECTOR, PowerProfilesSelectorClass))

typedef struct _PowerProfilesSelector PowerProfilesSelector;
typedef struct _PowerProfilesSelectorClass PowerProfilesSelectorClass;
typedef struct _PowerProfilesSelectorPrivate PowerProfilesSelectorPrivate;
typedef struct _PowerIndicatorPrivate PowerIndicatorPrivate;
typedef struct _SoundIndicatorPrivate SoundIndicatorPrivate;

#define TYPE_ADAPTER1 (adapter1_get_type ())
#define ADAPTER1(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ADAPTER1, Adapter1))
#define IS_ADAPTER1(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ADAPTER1))
#define ADAPTER1_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_ADAPTER1, Adapter1Iface))

typedef struct _Adapter1 Adapter1;
typedef struct _Adapter1Iface Adapter1Iface;

#define TYPE_ADAPTER1_PROXY (adapter1_proxy_get_type ())

#define TYPE_DEVICE1 (device1_get_type ())
#define DEVICE1(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DEVICE1, Device1))
#define IS_DEVICE1(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DEVICE1))
#define DEVICE1_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_DEVICE1, Device1Iface))

typedef struct _Device1 Device1;
typedef struct _Device1Iface Device1Iface;

#define TYPE_DEVICE1_PROXY (device1_proxy_get_type ())

#define TYPE_TRANSFER (transfer_get_type ())
#define TRANSFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TRANSFER, Transfer))
#define IS_TRANSFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TRANSFER))
#define TRANSFER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_TRANSFER, TransferIface))

typedef struct _Transfer Transfer;
typedef struct _TransferIface TransferIface;

#define TYPE_TRANSFER_PROXY (transfer_proxy_get_type ())

#define TYPE_SESSION (session_get_type ())
#define SESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SESSION, Session))
#define IS_SESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SESSION))
#define SESSION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_SESSION, SessionIface))

typedef struct _Session Session;
typedef struct _SessionIface SessionIface;

#define TYPE_SESSION_PROXY (session_proxy_get_type ())

#define TYPE_RFKILL (rfkill_get_type ())
#define RFKILL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_RFKILL, Rfkill))
#define IS_RFKILL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_RFKILL))
#define RFKILL_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_RFKILL, RfkillIface))

typedef struct _Rfkill Rfkill;
typedef struct _RfkillIface RfkillIface;

#define TYPE_RFKILL_PROXY (rfkill_proxy_get_type ())
typedef enum  {
	BATTERY_TYPE_NONE,
	BATTERY_TYPE_PERCENTAGE,
	BATTERY_TYPE_COARSE
} BatteryType;

#define TYPE_BATTERY_TYPE (battery_type_get_type ())
typedef enum  {
	BLUETOOTH_TYPE_ANY = 1 << 0,
	BLUETOOTH_TYPE_PHONE = 1 << 1,
	BLUETOOTH_TYPE_MODEM = 1 << 2,
	BLUETOOTH_TYPE_COMPUTER = 1 << 3,
	BLUETOOTH_TYPE_NETWORK = 1 << 4,
	BLUETOOTH_TYPE_HEADSET = 1 << 5,
	BLUETOOTH_TYPE_HEADPHONES = 1 << 6,
	BLUETOOTH_TYPE_OTHER_AUDIO = 1 << 7,
	BLUETOOTH_TYPE_KEYBOARD = 1 << 8,
	BLUETOOTH_TYPE_MOUSE = 1 << 9,
	BLUETOOTH_TYPE_CAMERA = 1 << 10,
	BLUETOOTH_TYPE_PRINTER = 1 << 11,
	BLUETOOTH_TYPE_JOYPAD = 1 << 12,
	BLUETOOTH_TYPE_TABLET = 1 << 13,
	BLUETOOTH_TYPE_VIDEO = 1 << 14,
	BLUETOOTH_TYPE_REMOTE_CONTROL = 1 << 15,
	BLUETOOTH_TYPE_SCANNER = 1 << 16,
	BLUETOOTH_TYPE_DISPLAY = 1 << 17,
	BLUETOOTH_TYPE_WEARABLE = 1 << 18,
	BLUETOOTH_TYPE_TOY = 1 << 19,
	BLUETOOTH_TYPE_SPEAKERS = 1 << 20
} BluetoothType;

#define TYPE_BLUETOOTH_TYPE (bluetooth_type_get_type ())
typedef enum  {
	POWER_STATE_ABSENT = 0,
	POWER_STATE_ON,
	POWER_STATE_TURNING_ON,
	POWER_STATE_TURNING_OFF,
	POWER_STATE_OFF
} PowerState;

#define TYPE_POWER_STATE (power_state_get_type ())
typedef struct _BluetoothIndicatorPrivate BluetoothIndicatorPrivate;

#define TYPE_BT_DEVICE_ROW (bt_device_row_get_type ())
#define BT_DEVICE_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BT_DEVICE_ROW, BTDeviceRow))
#define BT_DEVICE_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BT_DEVICE_ROW, BTDeviceRowClass))
#define IS_BT_DEVICE_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BT_DEVICE_ROW))
#define IS_BT_DEVICE_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BT_DEVICE_ROW))
#define BT_DEVICE_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BT_DEVICE_ROW, BTDeviceRowClass))

typedef struct _BTDeviceRow BTDeviceRow;
typedef struct _BTDeviceRowClass BTDeviceRowClass;
typedef struct _BTDeviceRowPrivate BTDeviceRowPrivate;

#define TYPE_OBEX_MANAGER (obex_manager_get_type ())
#define OBEX_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OBEX_MANAGER, ObexManager))
#define OBEX_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OBEX_MANAGER, ObexManagerClass))
#define IS_OBEX_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OBEX_MANAGER))
#define IS_OBEX_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OBEX_MANAGER))
#define OBEX_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OBEX_MANAGER, ObexManagerClass))

typedef struct _ObexManager ObexManager;
typedef struct _ObexManagerClass ObexManagerClass;
typedef struct _ObexManagerPrivate ObexManagerPrivate;

struct _StatusPlugin {
	PeasExtensionBase parent_instance;
	StatusPluginPrivate * priv;
};

struct _StatusPluginClass {
	PeasExtensionBaseClass parent_class;
};

struct _StatusSettings {
	GtkGrid parent_instance;
	StatusSettingsPrivate * priv;
};

struct _StatusSettingsClass {
	GtkGridClass parent_class;
};

struct _StatusApplet {
	BudgieApplet parent_instance;
	StatusAppletPrivate * priv;
	GtkBox* widget;
	BluetoothIndicator* blue;
	SoundIndicator* sound;
	PowerIndicator* power;
	GtkEventBox* wrap;
};

struct _StatusAppletClass {
	BudgieAppletClass parent_class;
};

struct _BatteryIcon {
	GtkBox parent_instance;
	BatteryIconPrivate * priv;
};

struct _BatteryIconClass {
	GtkBoxClass parent_class;
};

struct _PowerProfilesDBusIface {
	GTypeInterface parent_iface;
	GHashTable** (*get_profiles) (PowerProfilesDBus* self, gint* result_length1);
	gchar* (*get_active_profile) (PowerProfilesDBus* self);
	void (*set_active_profile) (PowerProfilesDBus* self, const gchar* value);
};

struct _PowerProfilesOption {
	GtkRadioButton parent_instance;
	PowerProfilesOptionPrivate * priv;
};

struct _PowerProfilesOptionClass {
	GtkRadioButtonClass parent_class;
};

struct _PowerProfilesSelector {
	GtkBox parent_instance;
	PowerProfilesSelectorPrivate * priv;
};

struct _PowerProfilesSelectorClass {
	GtkBoxClass parent_class;
};

struct _PowerIndicator {
	GtkBin parent_instance;
	PowerIndicatorPrivate * priv;
	GtkEventBox* ebox;
	BudgiePopover* popover;
};

struct _PowerIndicatorClass {
	GtkBinClass parent_class;
};

struct _SoundIndicator {
	GtkBin parent_instance;
	SoundIndicatorPrivate * priv;
	GtkEventBox* ebox;
	BudgiePopover* popover;
};

struct _SoundIndicatorClass {
	GtkBinClass parent_class;
};

struct _Adapter1Iface {
	GTypeInterface parent_iface;
	void (*start_discovery) (Adapter1* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*start_discovery_finish) (Adapter1* self, GAsyncResult* _res_, GError** error);
	void (*stop_discovery) (Adapter1* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*stop_discovery_finish) (Adapter1* self, GAsyncResult* _res_, GError** error);
	void (*remove_device) (Adapter1* self, const char* device, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*remove_device_finish) (Adapter1* self, GAsyncResult* _res_, GError** error);
	void (*set_discovery_filter) (Adapter1* self, GHashTable* properties, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*set_discovery_filter_finish) (Adapter1* self, GAsyncResult* _res_, GError** error);
	gchar* (*get_address) (Adapter1* self);
	gchar* (*get_name) (Adapter1* self);
	gchar* (*get_alias) (Adapter1* self);
	void (*set_alias) (Adapter1* self, const gchar* value);
	guint32 (*get_class) (Adapter1* self);
	gboolean (*get_powered) (Adapter1* self);
	void (*set_powered) (Adapter1* self, gboolean value);
	gchar* (*get_powered_state) (Adapter1* self);
	gboolean (*get_discoverable) (Adapter1* self);
	void (*set_discoverable) (Adapter1* self, gboolean value);
	guint32 (*get_discoverable_timeout) (Adapter1* self);
	void (*set_discoverable_timeout) (Adapter1* self, guint32 value);
	gboolean (*get_pairable) (Adapter1* self);
	void (*set_pairable) (Adapter1* self, gboolean value);
	guint32 (*get_pairable_timeout) (Adapter1* self);
	void (*set_pairable_timeout) (Adapter1* self, guint32 value);
	gboolean (*get_discovering) (Adapter1* self);
	void (*set_discovering) (Adapter1* self, gboolean value);
	gchar** (*get_UUIDS) (Adapter1* self, gint* result_length1);
	gchar* (*get_modalias) (Adapter1* self);
};

struct _Device1Iface {
	GTypeInterface parent_iface;
	void (*connect) (Device1* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_finish) (Device1* self, GAsyncResult* _res_, GError** error);
	void (*disconnect) (Device1* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*disconnect_finish) (Device1* self, GAsyncResult* _res_, GError** error);
	void (*connect_profile) (Device1* self, const gchar* uuid, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_profile_finish) (Device1* self, GAsyncResult* _res_, GError** error);
	void (*disconnect_profile) (Device1* self, const gchar* uuid, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*disconnect_profile_finish) (Device1* self, GAsyncResult* _res_, GError** error);
	void (*pair) (Device1* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*pair_finish) (Device1* self, GAsyncResult* _res_, GError** error);
	void (*cancel_pairing) (Device1* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*cancel_pairing_finish) (Device1* self, GAsyncResult* _res_, GError** error);
	gchar* (*get_address) (Device1* self);
	gchar* (*get_name) (Device1* self);
	gchar* (*get_alias) (Device1* self);
	void (*set_alias) (Device1* self, const gchar* value);
	guint32 (*get_class) (Device1* self);
	guint16 (*get_appearance) (Device1* self);
	gchar* (*get_icon) (Device1* self);
	gboolean (*get_paired) (Device1* self);
	gboolean (*get_trusted) (Device1* self);
	void (*set_trusted) (Device1* self, gboolean value);
	gboolean (*get_blocked) (Device1* self);
	void (*set_blocked) (Device1* self, gboolean value);
	gboolean (*get_legacy_pairing) (Device1* self);
	gint16 (*get_RSSI) (Device1* self);
	gboolean (*get_connected) (Device1* self);
	gchar** (*get_UUIDs) (Device1* self, gint* result_length1);
	gchar* (*get_modalias) (Device1* self);
	char* (*get_adapter) (Device1* self);
};

struct _TransferIface {
	GTypeInterface parent_iface;
	void (*cancel) (Transfer* self, GError** error);
	gchar* (*get_status) (Transfer* self);
	char* (*get_session) (Transfer* self);
	gchar* (*get_name) (Transfer* self);
	gchar* (*get_Type) (Transfer* self);
	guint64 (*get_time) (Transfer* self);
	guint64 (*get_size) (Transfer* self);
	guint64 (*get_transferred) (Transfer* self);
	gchar* (*get_filename) (Transfer* self);
};

struct _SessionIface {
	GTypeInterface parent_iface;
	gchar* (*get_source) (Session* self);
	gchar* (*get_destination) (Session* self);
	guchar (*get_channel) (Session* self);
	gchar* (*get_target) (Session* self);
	gchar* (*get_root) (Session* self);
};

struct _RfkillIface {
	GTypeInterface parent_iface;
	gboolean (*get_bluetooth_airplane_mode) (Rfkill* self);
	void (*set_bluetooth_airplane_mode) (Rfkill* self, gboolean value);
};

struct _BluetoothIndicator {
	GtkBin parent_instance;
	BluetoothIndicatorPrivate * priv;
	GtkImage* image;
	GtkEventBox* ebox;
	BudgiePopover* popover;
};

struct _BluetoothIndicatorClass {
	GtkBinClass parent_class;
};

struct _BTDeviceRow {
	GtkListBoxRow parent_instance;
	BTDeviceRowPrivate * priv;
	Transfer* transfer;
};

struct _BTDeviceRowClass {
	GtkListBoxRowClass parent_class;
};

struct _ObexManager {
	GObject parent_instance;
	ObexManagerPrivate * priv;
};

struct _ObexManagerClass {
	GObjectClass parent_class;
};

GType status_plugin_register_type (GTypeModule * module);
VALA_EXTERN GType status_plugin_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (StatusPlugin, g_object_unref)
VALA_EXTERN StatusPlugin* status_plugin_new (void);
VALA_EXTERN StatusPlugin* status_plugin_construct (GType object_type);
GType status_settings_register_type (GTypeModule * module);
VALA_EXTERN GType status_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (StatusSettings, g_object_unref)
VALA_EXTERN StatusSettings* status_settings_new (GSettings* settings);
VALA_EXTERN StatusSettings* status_settings_construct (GType object_type,
                                           GSettings* settings);
GType status_applet_register_type (GTypeModule * module);
VALA_EXTERN GType status_applet_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (StatusApplet, g_object_unref)
GType bluetooth_indicator_register_type (GTypeModule * module);
VALA_EXTERN GType bluetooth_indicator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BluetoothIndicator, g_object_unref)
GType sound_indicator_register_type (GTypeModule * module);
VALA_EXTERN GType sound_indicator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SoundIndicator, g_object_unref)
GType power_indicator_register_type (GTypeModule * module);
VALA_EXTERN GType power_indicator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PowerIndicator, g_object_unref)
VALA_EXTERN StatusApplet* status_applet_new (const gchar* uuid);
VALA_EXTERN StatusApplet* status_applet_construct (GType object_type,
                                       const gchar* uuid);
VALA_EXTERN const gchar* status_applet_get_uuid (StatusApplet* self);
VALA_EXTERN void status_applet_set_uuid (StatusApplet* self,
                             const gchar* value);
VALA_EXTERN void peas_register_types (GTypeModule* module);
GType battery_icon_register_type (GTypeModule * module);
VALA_EXTERN GType battery_icon_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BatteryIcon, g_object_unref)
VALA_EXTERN BatteryIcon* battery_icon_new (UpDevice* battery);
VALA_EXTERN BatteryIcon* battery_icon_construct (GType object_type,
                                     UpDevice* battery);
VALA_EXTERN void battery_icon_update_ui (BatteryIcon* self,
                             UpDevice* battery);
VALA_EXTERN UpDevice* battery_icon_get_battery (BatteryIcon* self);
VALA_EXTERN void battery_icon_set_battery (BatteryIcon* self,
                               UpDevice* value);
VALA_EXTERN gboolean battery_icon_get_label_visible (BatteryIcon* self);
VALA_EXTERN void battery_icon_set_label_visible (BatteryIcon* self,
                                     gboolean value);
GType power_profiles_dbus_register_type (GTypeModule * module);
VALA_EXTERN GType power_profiles_dbus_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PowerProfilesDBus, g_object_unref)
VALA_EXTERN GType power_profiles_dbus_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void power_profiles_dbus_proxy_register_dynamic_type (GTypeModule* module);
VALA_EXTERN guint power_profiles_dbus_register_object (void* object,
                                           GDBusConnection* connection,
                                           const gchar* path,
                                           GError** error);
VALA_EXTERN GHashTable** power_profiles_dbus_get_profiles (PowerProfilesDBus* self,
                                               gint* result_length1);
VALA_EXTERN gchar* power_profiles_dbus_get_active_profile (PowerProfilesDBus* self);
VALA_EXTERN void power_profiles_dbus_set_active_profile (PowerProfilesDBus* self,
                                             const gchar* value);
GType power_profiles_option_register_type (GTypeModule * module);
VALA_EXTERN GType power_profiles_option_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PowerProfilesOption, g_object_unref)
VALA_EXTERN PowerProfilesOption* power_profiles_option_new (PowerProfilesDBus* profiles_proxy,
                                                const gchar* profile_name,
                                                const gchar* display_name);
VALA_EXTERN PowerProfilesOption* power_profiles_option_construct (GType object_type,
                                                      PowerProfilesDBus* profiles_proxy,
                                                      const gchar* profile_name,
                                                      const gchar* display_name);
GType power_profiles_selector_register_type (GTypeModule * module);
VALA_EXTERN GType power_profiles_selector_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PowerProfilesSelector, g_object_unref)
VALA_EXTERN PowerProfilesSelector* power_profiles_selector_new (PowerProfilesDBus* profiles_proxy);
VALA_EXTERN PowerProfilesSelector* power_profiles_selector_construct (GType object_type,
                                                          PowerProfilesDBus* profiles_proxy);
VALA_EXTERN PowerIndicator* power_indicator_new (void);
VALA_EXTERN PowerIndicator* power_indicator_construct (GType object_type);
VALA_EXTERN void power_indicator_change_orientation (PowerIndicator* self,
                                         GtkOrientation orient);
VALA_EXTERN void power_indicator_update_labels (PowerIndicator* self,
                                    gboolean visible);
VALA_EXTERN UpClient* power_indicator_get_client (PowerIndicator* self);
VALA_EXTERN void power_indicator_set_client (PowerIndicator* self,
                                 UpClient* value);
VALA_EXTERN gboolean power_indicator_get_label_visible (PowerIndicator* self);
VALA_EXTERN void power_indicator_set_label_visible (PowerIndicator* self,
                                        gboolean value);
VALA_EXTERN SoundIndicator* sound_indicator_new (void);
VALA_EXTERN SoundIndicator* sound_indicator_construct (GType object_type);
VALA_EXTERN void sound_indicator_on_state_change (SoundIndicator* self,
                                      guint new_state);
VALA_EXTERN gboolean sound_indicator_on_scroll_event (SoundIndicator* self,
                                          GdkEventScroll* event);
VALA_EXTERN void sound_indicator_update_volume (SoundIndicator* self);
VALA_EXTERN GtkImage* sound_indicator_get_widget (SoundIndicator* self);
VALA_EXTERN void sound_indicator_set_widget (SoundIndicator* self,
                                 GtkImage* value);
VALA_EXTERN GvcMixerControl* sound_indicator_get_mixer (SoundIndicator* self);
VALA_EXTERN void sound_indicator_set_mixer (SoundIndicator* self,
                                GvcMixerControl* value);
VALA_EXTERN GType adapter1_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void adapter1_proxy_register_dynamic_type (GTypeModule* module);
VALA_EXTERN guint adapter1_register_object (void* object,
                                GDBusConnection* connection,
                                const gchar* path,
                                GError** error);
GType adapter1_register_type (GTypeModule * module);
VALA_EXTERN GType adapter1_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Adapter1, g_object_unref)
VALA_EXTERN void adapter1_start_discovery (Adapter1* self,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_);
VALA_EXTERN void adapter1_start_discovery_finish (Adapter1* self,
                                      GAsyncResult* _res_,
                                      GError** error);
VALA_EXTERN void adapter1_stop_discovery (Adapter1* self,
                              GAsyncReadyCallback _callback_,
                              gpointer _user_data_);
VALA_EXTERN void adapter1_stop_discovery_finish (Adapter1* self,
                                     GAsyncResult* _res_,
                                     GError** error);
VALA_EXTERN void adapter1_remove_device (Adapter1* self,
                             const char* device,
                             GAsyncReadyCallback _callback_,
                             gpointer _user_data_);
VALA_EXTERN void adapter1_remove_device_finish (Adapter1* self,
                                    GAsyncResult* _res_,
                                    GError** error);
VALA_EXTERN void adapter1_set_discovery_filter (Adapter1* self,
                                    GHashTable* properties,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN void adapter1_set_discovery_filter_finish (Adapter1* self,
                                           GAsyncResult* _res_,
                                           GError** error);
VALA_EXTERN gchar* adapter1_get_address (Adapter1* self);
VALA_EXTERN gchar* adapter1_get_name (Adapter1* self);
VALA_EXTERN gchar* adapter1_get_alias (Adapter1* self);
VALA_EXTERN void adapter1_set_alias (Adapter1* self,
                         const gchar* value);
VALA_EXTERN guint32 adapter1_get_class (Adapter1* self);
VALA_EXTERN gboolean adapter1_get_powered (Adapter1* self);
VALA_EXTERN void adapter1_set_powered (Adapter1* self,
                           gboolean value);
VALA_EXTERN gchar* adapter1_get_powered_state (Adapter1* self);
VALA_EXTERN gboolean adapter1_get_discoverable (Adapter1* self);
VALA_EXTERN void adapter1_set_discoverable (Adapter1* self,
                                gboolean value);
VALA_EXTERN guint32 adapter1_get_discoverable_timeout (Adapter1* self);
VALA_EXTERN void adapter1_set_discoverable_timeout (Adapter1* self,
                                        guint32 value);
VALA_EXTERN gboolean adapter1_get_pairable (Adapter1* self);
VALA_EXTERN void adapter1_set_pairable (Adapter1* self,
                            gboolean value);
VALA_EXTERN guint32 adapter1_get_pairable_timeout (Adapter1* self);
VALA_EXTERN void adapter1_set_pairable_timeout (Adapter1* self,
                                    guint32 value);
VALA_EXTERN gboolean adapter1_get_discovering (Adapter1* self);
VALA_EXTERN void adapter1_set_discovering (Adapter1* self,
                               gboolean value);
VALA_EXTERN gchar** adapter1_get_UUIDS (Adapter1* self,
                            gint* result_length1);
VALA_EXTERN gchar* adapter1_get_modalias (Adapter1* self);
VALA_EXTERN GType device1_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void device1_proxy_register_dynamic_type (GTypeModule* module);
VALA_EXTERN guint device1_register_object (void* object,
                               GDBusConnection* connection,
                               const gchar* path,
                               GError** error);
GType device1_register_type (GTypeModule * module);
VALA_EXTERN GType device1_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Device1, g_object_unref)
VALA_EXTERN void device1_connect (Device1* self,
                      GAsyncReadyCallback _callback_,
                      gpointer _user_data_);
VALA_EXTERN void device1_connect_finish (Device1* self,
                             GAsyncResult* _res_,
                             GError** error);
VALA_EXTERN void device1_disconnect (Device1* self,
                         GAsyncReadyCallback _callback_,
                         gpointer _user_data_);
VALA_EXTERN void device1_disconnect_finish (Device1* self,
                                GAsyncResult* _res_,
                                GError** error);
VALA_EXTERN void device1_connect_profile (Device1* self,
                              const gchar* uuid,
                              GAsyncReadyCallback _callback_,
                              gpointer _user_data_);
VALA_EXTERN void device1_connect_profile_finish (Device1* self,
                                     GAsyncResult* _res_,
                                     GError** error);
VALA_EXTERN void device1_disconnect_profile (Device1* self,
                                 const gchar* uuid,
                                 GAsyncReadyCallback _callback_,
                                 gpointer _user_data_);
VALA_EXTERN void device1_disconnect_profile_finish (Device1* self,
                                        GAsyncResult* _res_,
                                        GError** error);
VALA_EXTERN void device1_pair (Device1* self,
                   GAsyncReadyCallback _callback_,
                   gpointer _user_data_);
VALA_EXTERN void device1_pair_finish (Device1* self,
                          GAsyncResult* _res_,
                          GError** error);
VALA_EXTERN void device1_cancel_pairing (Device1* self,
                             GAsyncReadyCallback _callback_,
                             gpointer _user_data_);
VALA_EXTERN void device1_cancel_pairing_finish (Device1* self,
                                    GAsyncResult* _res_,
                                    GError** error);
VALA_EXTERN gchar* device1_get_address (Device1* self);
VALA_EXTERN gchar* device1_get_name (Device1* self);
VALA_EXTERN gchar* device1_get_alias (Device1* self);
VALA_EXTERN void device1_set_alias (Device1* self,
                        const gchar* value);
VALA_EXTERN guint32 device1_get_class (Device1* self);
VALA_EXTERN guint16 device1_get_appearance (Device1* self);
VALA_EXTERN gchar* device1_get_icon (Device1* self);
VALA_EXTERN gboolean device1_get_paired (Device1* self);
VALA_EXTERN gboolean device1_get_trusted (Device1* self);
VALA_EXTERN void device1_set_trusted (Device1* self,
                          gboolean value);
VALA_EXTERN gboolean device1_get_blocked (Device1* self);
VALA_EXTERN void device1_set_blocked (Device1* self,
                          gboolean value);
VALA_EXTERN gboolean device1_get_legacy_pairing (Device1* self);
VALA_EXTERN gint16 device1_get_RSSI (Device1* self);
VALA_EXTERN gboolean device1_get_connected (Device1* self);
VALA_EXTERN gchar** device1_get_UUIDs (Device1* self,
                           gint* result_length1);
VALA_EXTERN gchar* device1_get_modalias (Device1* self);
VALA_EXTERN char* device1_get_adapter (Device1* self);
VALA_EXTERN GType transfer_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void transfer_proxy_register_dynamic_type (GTypeModule* module);
VALA_EXTERN guint transfer_register_object (void* object,
                                GDBusConnection* connection,
                                const gchar* path,
                                GError** error);
GType transfer_register_type (GTypeModule * module);
VALA_EXTERN GType transfer_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Transfer, g_object_unref)
VALA_EXTERN void transfer_cancel (Transfer* self,
                      GError** error);
VALA_EXTERN gchar* transfer_get_status (Transfer* self);
VALA_EXTERN char* transfer_get_session (Transfer* self);
VALA_EXTERN gchar* transfer_get_name (Transfer* self);
VALA_EXTERN gchar* transfer_get_Type (Transfer* self);
VALA_EXTERN guint64 transfer_get_time (Transfer* self);
VALA_EXTERN guint64 transfer_get_size (Transfer* self);
VALA_EXTERN guint64 transfer_get_transferred (Transfer* self);
VALA_EXTERN gchar* transfer_get_filename (Transfer* self);
GType session_register_type (GTypeModule * module);
VALA_EXTERN GType session_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Session, g_object_unref)
VALA_EXTERN GType session_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void session_proxy_register_dynamic_type (GTypeModule* module);
VALA_EXTERN guint session_register_object (void* object,
                               GDBusConnection* connection,
                               const gchar* path,
                               GError** error);
VALA_EXTERN gchar* session_get_source (Session* self);
VALA_EXTERN gchar* session_get_destination (Session* self);
VALA_EXTERN guchar session_get_channel (Session* self);
VALA_EXTERN gchar* session_get_target (Session* self);
VALA_EXTERN gchar* session_get_root (Session* self);
GType rfkill_register_type (GTypeModule * module);
VALA_EXTERN GType rfkill_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Rfkill, g_object_unref)
VALA_EXTERN GType rfkill_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void rfkill_proxy_register_dynamic_type (GTypeModule* module);
VALA_EXTERN guint rfkill_register_object (void* object,
                              GDBusConnection* connection,
                              const gchar* path,
                              GError** error);
VALA_EXTERN gboolean rfkill_get_bluetooth_airplane_mode (Rfkill* self);
VALA_EXTERN void rfkill_set_bluetooth_airplane_mode (Rfkill* self,
                                         gboolean value);
VALA_EXTERN GType battery_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType bluetooth_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType power_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN PowerState power_state_from_string (const gchar* state);
VALA_EXTERN BluetoothIndicator* bluetooth_indicator_new (void);
VALA_EXTERN BluetoothIndicator* bluetooth_indicator_construct (GType object_type);
GType bt_device_row_register_type (GTypeModule * module);
VALA_EXTERN GType bt_device_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BTDeviceRow, g_object_unref)
GType obex_manager_register_type (GTypeModule * module);
VALA_EXTERN GType obex_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObexManager, g_object_unref)
VALA_EXTERN BTDeviceRow* bt_device_row_new (Device1* device,
                                ObexManager* obex_manager);
VALA_EXTERN BTDeviceRow* bt_device_row_construct (GType object_type,
                                      Device1* device,
                                      ObexManager* obex_manager);
VALA_EXTERN void bt_device_row_toggle_connection (BTDeviceRow* self,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_);
VALA_EXTERN void bt_device_row_toggle_connection_finish (BTDeviceRow* self,
                                             GAsyncResult* _res_);
VALA_EXTERN Device1* bt_device_row_get_device (BTDeviceRow* self);
VALA_EXTERN ObexManager* bt_device_row_get_obex_manager (BTDeviceRow* self);
VALA_EXTERN UpDevice* bt_device_row_get_up_device (BTDeviceRow* self);
VALA_EXTERN void bt_device_row_set_up_device (BTDeviceRow* self,
                                  UpDevice* value);
VALA_EXTERN ObexManager* obex_manager_new (void);
VALA_EXTERN ObexManager* obex_manager_construct (GType object_type);

G_END_DECLS

#endif
