/* settings_panel_dialogs.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from settings_panel_dialogs.vala, do not modify */

/*
 * This file is part of budgie-desktop
 *
 * Copyright Budgie Desktop Developers
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <glib/gi18n-lib.h>
#include <pango/pango.h>
#include <gio/gio.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define BUDGIE_TYPE_REMOVE_PANEL_DIALOG (budgie_remove_panel_dialog_get_type ())
#define BUDGIE_REMOVE_PANEL_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BUDGIE_TYPE_REMOVE_PANEL_DIALOG, BudgieRemovePanelDialog))
#define BUDGIE_REMOVE_PANEL_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BUDGIE_TYPE_REMOVE_PANEL_DIALOG, BudgieRemovePanelDialogClass))
#define BUDGIE_IS_REMOVE_PANEL_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BUDGIE_TYPE_REMOVE_PANEL_DIALOG))
#define BUDGIE_IS_REMOVE_PANEL_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BUDGIE_TYPE_REMOVE_PANEL_DIALOG))
#define BUDGIE_REMOVE_PANEL_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BUDGIE_TYPE_REMOVE_PANEL_DIALOG, BudgieRemovePanelDialogClass))

typedef struct _BudgieRemovePanelDialog BudgieRemovePanelDialog;
typedef struct _BudgieRemovePanelDialogClass BudgieRemovePanelDialogClass;
typedef struct _BudgieRemovePanelDialogPrivate BudgieRemovePanelDialogPrivate;
enum  {
	BUDGIE_REMOVE_PANEL_DIALOG_0_PROPERTY,
	BUDGIE_REMOVE_PANEL_DIALOG_NUM_PROPERTIES
};
static GParamSpec* budgie_remove_panel_dialog_properties[BUDGIE_REMOVE_PANEL_DIALOG_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BUDGIE_TYPE_REMOVE_APPLET_DIALOG (budgie_remove_applet_dialog_get_type ())
#define BUDGIE_REMOVE_APPLET_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BUDGIE_TYPE_REMOVE_APPLET_DIALOG, BudgieRemoveAppletDialog))
#define BUDGIE_REMOVE_APPLET_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BUDGIE_TYPE_REMOVE_APPLET_DIALOG, BudgieRemoveAppletDialogClass))
#define BUDGIE_IS_REMOVE_APPLET_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BUDGIE_TYPE_REMOVE_APPLET_DIALOG))
#define BUDGIE_IS_REMOVE_APPLET_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BUDGIE_TYPE_REMOVE_APPLET_DIALOG))
#define BUDGIE_REMOVE_APPLET_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BUDGIE_TYPE_REMOVE_APPLET_DIALOG, BudgieRemoveAppletDialogClass))

typedef struct _BudgieRemoveAppletDialog BudgieRemoveAppletDialog;
typedef struct _BudgieRemoveAppletDialogClass BudgieRemoveAppletDialogClass;
typedef struct _BudgieRemoveAppletDialogPrivate BudgieRemoveAppletDialogPrivate;
enum  {
	BUDGIE_REMOVE_APPLET_DIALOG_0_PROPERTY,
	BUDGIE_REMOVE_APPLET_DIALOG_NUM_PROPERTIES
};
static GParamSpec* budgie_remove_applet_dialog_properties[BUDGIE_REMOVE_APPLET_DIALOG_NUM_PROPERTIES];

#define BUDGIE_TYPE_REMOVE_RAVEN_WIDGET_DIALOG (budgie_remove_raven_widget_dialog_get_type ())
#define BUDGIE_REMOVE_RAVEN_WIDGET_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BUDGIE_TYPE_REMOVE_RAVEN_WIDGET_DIALOG, BudgieRemoveRavenWidgetDialog))
#define BUDGIE_REMOVE_RAVEN_WIDGET_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BUDGIE_TYPE_REMOVE_RAVEN_WIDGET_DIALOG, BudgieRemoveRavenWidgetDialogClass))
#define BUDGIE_IS_REMOVE_RAVEN_WIDGET_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BUDGIE_TYPE_REMOVE_RAVEN_WIDGET_DIALOG))
#define BUDGIE_IS_REMOVE_RAVEN_WIDGET_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BUDGIE_TYPE_REMOVE_RAVEN_WIDGET_DIALOG))
#define BUDGIE_REMOVE_RAVEN_WIDGET_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BUDGIE_TYPE_REMOVE_RAVEN_WIDGET_DIALOG, BudgieRemoveRavenWidgetDialogClass))

typedef struct _BudgieRemoveRavenWidgetDialog BudgieRemoveRavenWidgetDialog;
typedef struct _BudgieRemoveRavenWidgetDialogClass BudgieRemoveRavenWidgetDialogClass;
typedef struct _BudgieRemoveRavenWidgetDialogPrivate BudgieRemoveRavenWidgetDialogPrivate;
enum  {
	BUDGIE_REMOVE_RAVEN_WIDGET_DIALOG_0_PROPERTY,
	BUDGIE_REMOVE_RAVEN_WIDGET_DIALOG_NUM_PROPERTIES
};
static GParamSpec* budgie_remove_raven_widget_dialog_properties[BUDGIE_REMOVE_RAVEN_WIDGET_DIALOG_NUM_PROPERTIES];

struct _BudgieRemovePanelDialog {
	GtkDialog parent_instance;
	BudgieRemovePanelDialogPrivate * priv;
};

struct _BudgieRemovePanelDialogClass {
	GtkDialogClass parent_class;
};

struct _BudgieRemovePanelDialogPrivate {
	GtkLabel* confirm_label;
	GtkImage* confirm_image;
};

struct _BudgieRemoveAppletDialog {
	GtkDialog parent_instance;
	BudgieRemoveAppletDialogPrivate * priv;
};

struct _BudgieRemoveAppletDialogClass {
	GtkDialogClass parent_class;
};

struct _BudgieRemoveAppletDialogPrivate {
	GSettings* settings;
	GtkCheckButton* check_confirm;
	GtkLabel* confirm_label;
	GtkImage* confirm_image;
};

struct _BudgieRemoveRavenWidgetDialog {
	GtkDialog parent_instance;
	BudgieRemoveRavenWidgetDialogPrivate * priv;
};

struct _BudgieRemoveRavenWidgetDialogClass {
	GtkDialogClass parent_class;
};

struct _BudgieRemoveRavenWidgetDialogPrivate {
	GSettings* settings;
	GtkCheckButton* check_confirm;
	GtkLabel* confirm_label;
	GtkImage* confirm_image;
};

static gint BudgieRemovePanelDialog_private_offset;
static gpointer budgie_remove_panel_dialog_parent_class = NULL;
static gint BudgieRemoveAppletDialog_private_offset;
static gpointer budgie_remove_applet_dialog_parent_class = NULL;
static gint BudgieRemoveRavenWidgetDialog_private_offset;
static gpointer budgie_remove_raven_widget_dialog_parent_class = NULL;

VALA_EXTERN GType budgie_remove_panel_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieRemovePanelDialog, g_object_unref)
VALA_EXTERN BudgieRemovePanelDialog* budgie_remove_panel_dialog_new (GtkWindow* parent);
VALA_EXTERN BudgieRemovePanelDialog* budgie_remove_panel_dialog_construct (GType object_type,
                                                               GtkWindow* parent);
VALA_EXTERN gboolean budgie_remove_panel_dialog_run (BudgieRemovePanelDialog* self);
static void budgie_remove_panel_dialog_finalize (GObject * obj);
static GType budgie_remove_panel_dialog_get_type_once (void);
VALA_EXTERN GType budgie_remove_applet_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieRemoveAppletDialog, g_object_unref)
VALA_EXTERN BudgieRemoveAppletDialog* budgie_remove_applet_dialog_new (GtkWindow* parent);
VALA_EXTERN BudgieRemoveAppletDialog* budgie_remove_applet_dialog_construct (GType object_type,
                                                                 GtkWindow* parent);
VALA_EXTERN gboolean budgie_remove_applet_dialog_run (BudgieRemoveAppletDialog* self);
static void budgie_remove_applet_dialog_finalize (GObject * obj);
static GType budgie_remove_applet_dialog_get_type_once (void);
VALA_EXTERN GType budgie_remove_raven_widget_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieRemoveRavenWidgetDialog, g_object_unref)
VALA_EXTERN BudgieRemoveRavenWidgetDialog* budgie_remove_raven_widget_dialog_new (GtkWindow* parent);
VALA_EXTERN BudgieRemoveRavenWidgetDialog* budgie_remove_raven_widget_dialog_construct (GType object_type,
                                                                            GtkWindow* parent);
VALA_EXTERN gboolean budgie_remove_raven_widget_dialog_run (BudgieRemoveRavenWidgetDialog* self);
static void budgie_remove_raven_widget_dialog_finalize (GObject * obj);
static GType budgie_remove_raven_widget_dialog_get_type_once (void);

static inline gpointer
budgie_remove_panel_dialog_get_instance_private (BudgieRemovePanelDialog* self)
{
	return G_STRUCT_MEMBER_P (self, BudgieRemovePanelDialog_private_offset);
}

BudgieRemovePanelDialog*
budgie_remove_panel_dialog_construct (GType object_type,
                                      GtkWindow* parent)
{
	BudgieRemovePanelDialog * self = NULL;
	GtkBox* content = NULL;
	GtkBox* _tmp0_;
	GtkBox* box = NULL;
	GtkBox* _tmp1_;
	GtkImage* _tmp2_;
	GtkLabel* _tmp3_;
	GtkLabel* _tmp4_;
	GtkLabel* _tmp5_;
	GtkImage* _tmp6_;
	GtkImage* _tmp7_;
	GtkLabel* _tmp8_;
	GtkWidget* _tmp9_;
	GtkStyleContext* _tmp10_;
	GtkWidget* _tmp11_;
	GtkStyleContext* _tmp12_;
	g_return_val_if_fail (parent != NULL, NULL);
	self = (BudgieRemovePanelDialog*) g_object_new (object_type, "use-header-bar", 1, "transient-for", parent, "title", _ ("Confirm panel removal"), "modal", TRUE, NULL);
	_tmp0_ = gtk_dialog_get_content_area ((GtkDialog*) self);
	content = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_box_get_type ()) ? ((GtkBox*) _tmp0_) : NULL;
	_tmp1_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
	g_object_ref_sink (_tmp1_);
	box = _tmp1_;
	_tmp2_ = (GtkImage*) gtk_image_new_from_icon_name ("edit-delete-symbolic", (GtkIconSize) GTK_ICON_SIZE_DIALOG);
	g_object_ref_sink (_tmp2_);
	_g_object_unref0 (self->priv->confirm_image);
	self->priv->confirm_image = _tmp2_;
	_tmp3_ = (GtkLabel*) gtk_label_new (_ ("Do you really want to remove this panel? This action cannot be undone."));
	g_object_ref_sink (_tmp3_);
	_g_object_unref0 (self->priv->confirm_label);
	self->priv->confirm_label = _tmp3_;
	_tmp4_ = self->priv->confirm_label;
	gtk_label_set_line_wrap_mode (_tmp4_, PANGO_WRAP_WORD);
	_tmp5_ = self->priv->confirm_label;
	gtk_label_set_line_wrap (_tmp5_, TRUE);
	_tmp6_ = self->priv->confirm_image;
	gtk_box_pack_start (box, (GtkWidget*) _tmp6_, FALSE, FALSE, (guint) 0);
	_tmp7_ = self->priv->confirm_image;
	gtk_widget_set_margin_end ((GtkWidget*) _tmp7_, 12);
	_tmp8_ = self->priv->confirm_label;
	gtk_box_pack_start (box, (GtkWidget*) _tmp8_, FALSE, FALSE, (guint) 0);
	gtk_box_pack_start (content, (GtkWidget*) box, FALSE, FALSE, (guint) 0);
	g_object_set ((GtkWidget*) content, "margin", 12, NULL);
	gtk_widget_show_all ((GtkWidget*) content);
	_tmp9_ = gtk_dialog_add_button ((GtkDialog*) self, _ ("Remove panel"), (gint) GTK_RESPONSE_ACCEPT);
	_tmp10_ = gtk_widget_get_style_context (_tmp9_);
	gtk_style_context_add_class (_tmp10_, GTK_STYLE_CLASS_DESTRUCTIVE_ACTION);
	_tmp11_ = gtk_dialog_add_button ((GtkDialog*) self, _ ("Keep panel"), (gint) GTK_RESPONSE_CANCEL);
	_tmp12_ = gtk_widget_get_style_context (_tmp11_);
	gtk_style_context_add_class (_tmp12_, GTK_STYLE_CLASS_SUGGESTED_ACTION);
	_g_object_unref0 (box);
	return self;
}

BudgieRemovePanelDialog*
budgie_remove_panel_dialog_new (GtkWindow* parent)
{
	return budgie_remove_panel_dialog_construct (BUDGIE_TYPE_REMOVE_PANEL_DIALOG, parent);
}

/**
* Simple wrapper to ensure dialog always does the right thing
*/
gboolean
budgie_remove_panel_dialog_run (BudgieRemovePanelDialog* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog)) == ((gint) GTK_RESPONSE_ACCEPT);
	return result;
}

static void
budgie_remove_panel_dialog_class_init (BudgieRemovePanelDialogClass * klass,
                                       gpointer klass_data)
{
	budgie_remove_panel_dialog_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &BudgieRemovePanelDialog_private_offset);
	G_OBJECT_CLASS (klass)->finalize = budgie_remove_panel_dialog_finalize;
}

static void
budgie_remove_panel_dialog_instance_init (BudgieRemovePanelDialog * self,
                                          gpointer klass)
{
	self->priv = budgie_remove_panel_dialog_get_instance_private (self);
}

static void
budgie_remove_panel_dialog_finalize (GObject * obj)
{
	BudgieRemovePanelDialog * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BUDGIE_TYPE_REMOVE_PANEL_DIALOG, BudgieRemovePanelDialog);
	_g_object_unref0 (self->priv->confirm_label);
	_g_object_unref0 (self->priv->confirm_image);
	G_OBJECT_CLASS (budgie_remove_panel_dialog_parent_class)->finalize (obj);
}

/**
* RemovePanelDialog is used to confirm whether the panel should *really* be
* removed
*/
static GType
budgie_remove_panel_dialog_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BudgieRemovePanelDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) budgie_remove_panel_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BudgieRemovePanelDialog), 0, (GInstanceInitFunc) budgie_remove_panel_dialog_instance_init, NULL };
	GType budgie_remove_panel_dialog_type_id;
	budgie_remove_panel_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "BudgieRemovePanelDialog", &g_define_type_info, 0);
	BudgieRemovePanelDialog_private_offset = g_type_add_instance_private (budgie_remove_panel_dialog_type_id, sizeof (BudgieRemovePanelDialogPrivate));
	return budgie_remove_panel_dialog_type_id;
}

GType
budgie_remove_panel_dialog_get_type (void)
{
	static volatile gsize budgie_remove_panel_dialog_type_id__once = 0;
	if (g_once_init_enter (&budgie_remove_panel_dialog_type_id__once)) {
		GType budgie_remove_panel_dialog_type_id;
		budgie_remove_panel_dialog_type_id = budgie_remove_panel_dialog_get_type_once ();
		g_once_init_leave (&budgie_remove_panel_dialog_type_id__once, budgie_remove_panel_dialog_type_id);
	}
	return budgie_remove_panel_dialog_type_id__once;
}

static inline gpointer
budgie_remove_applet_dialog_get_instance_private (BudgieRemoveAppletDialog* self)
{
	return G_STRUCT_MEMBER_P (self, BudgieRemoveAppletDialog_private_offset);
}

BudgieRemoveAppletDialog*
budgie_remove_applet_dialog_construct (GType object_type,
                                       GtkWindow* parent)
{
	BudgieRemoveAppletDialog * self = NULL;
	GtkBox* content = NULL;
	GtkBox* _tmp0_;
	GtkBox* box = NULL;
	GtkBox* _tmp1_;
	GtkImage* _tmp2_;
	GtkLabel* _tmp3_;
	GtkLabel* _tmp4_;
	GtkLabel* _tmp5_;
	GtkImage* _tmp6_;
	GtkImage* _tmp7_;
	GtkLabel* _tmp8_;
	GtkSeparator* sep = NULL;
	GtkSeparator* _tmp9_;
	GtkCheckButton* _tmp10_;
	GtkCheckButton* _tmp11_;
	GSettings* _tmp12_;
	GSettings* _tmp13_;
	GtkCheckButton* _tmp14_;
	GtkCheckButton* _tmp15_;
	GtkCheckButton* _tmp16_;
	GtkWidget* _tmp17_;
	GtkStyleContext* _tmp18_;
	GtkWidget* _tmp19_;
	GtkStyleContext* _tmp20_;
	g_return_val_if_fail (parent != NULL, NULL);
	self = (BudgieRemoveAppletDialog*) g_object_new (object_type, "use-header-bar", 1, "transient-for", parent, "title", _ ("Confirm applet removal"), "modal", TRUE, NULL);
	_tmp0_ = gtk_dialog_get_content_area ((GtkDialog*) self);
	content = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_box_get_type ()) ? ((GtkBox*) _tmp0_) : NULL;
	_tmp1_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
	g_object_ref_sink (_tmp1_);
	box = _tmp1_;
	_tmp2_ = (GtkImage*) gtk_image_new_from_icon_name ("edit-delete-symbolic", (GtkIconSize) GTK_ICON_SIZE_DIALOG);
	g_object_ref_sink (_tmp2_);
	_g_object_unref0 (self->priv->confirm_image);
	self->priv->confirm_image = _tmp2_;
	_tmp3_ = (GtkLabel*) gtk_label_new (_ ("Do you really want to remove this applet? This action cannot be undone" \
"."));
	g_object_ref_sink (_tmp3_);
	_g_object_unref0 (self->priv->confirm_label);
	self->priv->confirm_label = _tmp3_;
	_tmp4_ = self->priv->confirm_label;
	gtk_label_set_line_wrap_mode (_tmp4_, PANGO_WRAP_WORD);
	_tmp5_ = self->priv->confirm_label;
	gtk_label_set_line_wrap (_tmp5_, TRUE);
	_tmp6_ = self->priv->confirm_image;
	gtk_box_pack_start (box, (GtkWidget*) _tmp6_, FALSE, FALSE, (guint) 0);
	_tmp7_ = self->priv->confirm_image;
	gtk_widget_set_margin_end ((GtkWidget*) _tmp7_, 12);
	_tmp8_ = self->priv->confirm_label;
	gtk_box_pack_start (box, (GtkWidget*) _tmp8_, FALSE, FALSE, (guint) 0);
	gtk_box_pack_start (content, (GtkWidget*) box, FALSE, FALSE, (guint) 0);
	g_object_set ((GtkWidget*) content, "margin", 12, NULL);
	_tmp9_ = (GtkSeparator*) gtk_separator_new (GTK_ORIENTATION_VERTICAL);
	g_object_ref_sink (_tmp9_);
	sep = _tmp9_;
	gtk_widget_set_margin_top ((GtkWidget*) sep, 6);
	gtk_widget_set_margin_bottom ((GtkWidget*) sep, 6);
	gtk_box_pack_start (content, (GtkWidget*) sep, FALSE, FALSE, (guint) 0);
	_tmp10_ = (GtkCheckButton*) gtk_check_button_new_with_label (_ ("Don't ask me again"));
	g_object_ref_sink (_tmp10_);
	_g_object_unref0 (self->priv->check_confirm);
	self->priv->check_confirm = _tmp10_;
	_tmp11_ = self->priv->check_confirm;
	gtk_widget_set_halign ((GtkWidget*) _tmp11_, GTK_ALIGN_START);
	_tmp12_ = g_settings_new ("com.solus-project.budgie-panel");
	_g_object_unref0 (self->priv->settings);
	self->priv->settings = _tmp12_;
	_tmp13_ = self->priv->settings;
	_tmp14_ = self->priv->check_confirm;
	g_settings_bind (_tmp13_, "confirm-remove-applet", (GObject*) _tmp14_, "active", G_SETTINGS_BIND_DEFAULT | G_SETTINGS_BIND_INVERT_BOOLEAN);
	_tmp15_ = self->priv->check_confirm;
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp15_, 6);
	_tmp16_ = self->priv->check_confirm;
	gtk_box_pack_end (content, (GtkWidget*) _tmp16_, FALSE, FALSE, (guint) 0);
	gtk_widget_show_all ((GtkWidget*) content);
	_tmp17_ = gtk_dialog_add_button ((GtkDialog*) self, _ ("Remove applet"), (gint) GTK_RESPONSE_ACCEPT);
	_tmp18_ = gtk_widget_get_style_context (_tmp17_);
	gtk_style_context_add_class (_tmp18_, GTK_STYLE_CLASS_DESTRUCTIVE_ACTION);
	_tmp19_ = gtk_dialog_add_button ((GtkDialog*) self, _ ("Keep applet"), (gint) GTK_RESPONSE_CANCEL);
	_tmp20_ = gtk_widget_get_style_context (_tmp19_);
	gtk_style_context_add_class (_tmp20_, GTK_STYLE_CLASS_SUGGESTED_ACTION);
	_g_object_unref0 (sep);
	_g_object_unref0 (box);
	return self;
}

BudgieRemoveAppletDialog*
budgie_remove_applet_dialog_new (GtkWindow* parent)
{
	return budgie_remove_applet_dialog_construct (BUDGIE_TYPE_REMOVE_APPLET_DIALOG, parent);
}

/**
* Simple wrapper to ensure dialog always does the right thing
*/
gboolean
budgie_remove_applet_dialog_run (BudgieRemoveAppletDialog* self)
{
	GSettings* _tmp0_;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->settings;
	if (!g_settings_get_boolean (_tmp0_, "confirm-remove-applet")) {
		result = TRUE;
		return result;
	}
	result = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog)) == ((gint) GTK_RESPONSE_ACCEPT);
	return result;
}

static void
budgie_remove_applet_dialog_class_init (BudgieRemoveAppletDialogClass * klass,
                                        gpointer klass_data)
{
	budgie_remove_applet_dialog_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &BudgieRemoveAppletDialog_private_offset);
	G_OBJECT_CLASS (klass)->finalize = budgie_remove_applet_dialog_finalize;
}

static void
budgie_remove_applet_dialog_instance_init (BudgieRemoveAppletDialog * self,
                                           gpointer klass)
{
	self->priv = budgie_remove_applet_dialog_get_instance_private (self);
}

static void
budgie_remove_applet_dialog_finalize (GObject * obj)
{
	BudgieRemoveAppletDialog * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BUDGIE_TYPE_REMOVE_APPLET_DIALOG, BudgieRemoveAppletDialog);
	_g_object_unref0 (self->priv->settings);
	_g_object_unref0 (self->priv->check_confirm);
	_g_object_unref0 (self->priv->confirm_label);
	_g_object_unref0 (self->priv->confirm_image);
	G_OBJECT_CLASS (budgie_remove_applet_dialog_parent_class)->finalize (obj);
}

/**
* RemoveAppletDialog is used to confirm whether the applet should *really* be
* removed
*/
static GType
budgie_remove_applet_dialog_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BudgieRemoveAppletDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) budgie_remove_applet_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BudgieRemoveAppletDialog), 0, (GInstanceInitFunc) budgie_remove_applet_dialog_instance_init, NULL };
	GType budgie_remove_applet_dialog_type_id;
	budgie_remove_applet_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "BudgieRemoveAppletDialog", &g_define_type_info, 0);
	BudgieRemoveAppletDialog_private_offset = g_type_add_instance_private (budgie_remove_applet_dialog_type_id, sizeof (BudgieRemoveAppletDialogPrivate));
	return budgie_remove_applet_dialog_type_id;
}

GType
budgie_remove_applet_dialog_get_type (void)
{
	static volatile gsize budgie_remove_applet_dialog_type_id__once = 0;
	if (g_once_init_enter (&budgie_remove_applet_dialog_type_id__once)) {
		GType budgie_remove_applet_dialog_type_id;
		budgie_remove_applet_dialog_type_id = budgie_remove_applet_dialog_get_type_once ();
		g_once_init_leave (&budgie_remove_applet_dialog_type_id__once, budgie_remove_applet_dialog_type_id);
	}
	return budgie_remove_applet_dialog_type_id__once;
}

static inline gpointer
budgie_remove_raven_widget_dialog_get_instance_private (BudgieRemoveRavenWidgetDialog* self)
{
	return G_STRUCT_MEMBER_P (self, BudgieRemoveRavenWidgetDialog_private_offset);
}

BudgieRemoveRavenWidgetDialog*
budgie_remove_raven_widget_dialog_construct (GType object_type,
                                             GtkWindow* parent)
{
	BudgieRemoveRavenWidgetDialog * self = NULL;
	GtkBox* content = NULL;
	GtkBox* _tmp0_;
	GtkBox* box = NULL;
	GtkBox* _tmp1_;
	GtkImage* _tmp2_;
	GtkLabel* _tmp3_;
	GtkLabel* _tmp4_;
	GtkLabel* _tmp5_;
	GtkImage* _tmp6_;
	GtkImage* _tmp7_;
	GtkLabel* _tmp8_;
	GtkSeparator* sep = NULL;
	GtkSeparator* _tmp9_;
	GtkCheckButton* _tmp10_;
	GtkCheckButton* _tmp11_;
	GSettings* _tmp12_;
	GSettings* _tmp13_;
	GtkCheckButton* _tmp14_;
	GtkCheckButton* _tmp15_;
	GtkCheckButton* _tmp16_;
	GtkWidget* _tmp17_;
	GtkStyleContext* _tmp18_;
	GtkWidget* _tmp19_;
	GtkStyleContext* _tmp20_;
	g_return_val_if_fail (parent != NULL, NULL);
	self = (BudgieRemoveRavenWidgetDialog*) g_object_new (object_type, "use-header-bar", 1, "transient-for", parent, "title", _ ("Confirm widget removal"), "modal", TRUE, NULL);
	_tmp0_ = gtk_dialog_get_content_area ((GtkDialog*) self);
	content = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_box_get_type ()) ? ((GtkBox*) _tmp0_) : NULL;
	_tmp1_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
	g_object_ref_sink (_tmp1_);
	box = _tmp1_;
	_tmp2_ = (GtkImage*) gtk_image_new_from_icon_name ("edit-delete-symbolic", (GtkIconSize) GTK_ICON_SIZE_DIALOG);
	g_object_ref_sink (_tmp2_);
	_g_object_unref0 (self->priv->confirm_image);
	self->priv->confirm_image = _tmp2_;
	_tmp3_ = (GtkLabel*) gtk_label_new (_ ("Do you really want to remove this widget? This action cannot be undone" \
"."));
	g_object_ref_sink (_tmp3_);
	_g_object_unref0 (self->priv->confirm_label);
	self->priv->confirm_label = _tmp3_;
	_tmp4_ = self->priv->confirm_label;
	gtk_label_set_line_wrap_mode (_tmp4_, PANGO_WRAP_WORD);
	_tmp5_ = self->priv->confirm_label;
	gtk_label_set_line_wrap (_tmp5_, TRUE);
	_tmp6_ = self->priv->confirm_image;
	gtk_box_pack_start (box, (GtkWidget*) _tmp6_, FALSE, FALSE, (guint) 0);
	_tmp7_ = self->priv->confirm_image;
	gtk_widget_set_margin_end ((GtkWidget*) _tmp7_, 12);
	_tmp8_ = self->priv->confirm_label;
	gtk_box_pack_start (box, (GtkWidget*) _tmp8_, FALSE, FALSE, (guint) 0);
	gtk_box_pack_start (content, (GtkWidget*) box, FALSE, FALSE, (guint) 0);
	g_object_set ((GtkWidget*) content, "margin", 12, NULL);
	_tmp9_ = (GtkSeparator*) gtk_separator_new (GTK_ORIENTATION_VERTICAL);
	g_object_ref_sink (_tmp9_);
	sep = _tmp9_;
	gtk_widget_set_margin_top ((GtkWidget*) sep, 6);
	gtk_widget_set_margin_bottom ((GtkWidget*) sep, 6);
	gtk_box_pack_start (content, (GtkWidget*) sep, FALSE, FALSE, (guint) 0);
	_tmp10_ = (GtkCheckButton*) gtk_check_button_new_with_label (_ ("Don't ask me again"));
	g_object_ref_sink (_tmp10_);
	_g_object_unref0 (self->priv->check_confirm);
	self->priv->check_confirm = _tmp10_;
	_tmp11_ = self->priv->check_confirm;
	gtk_widget_set_halign ((GtkWidget*) _tmp11_, GTK_ALIGN_START);
	_tmp12_ = g_settings_new ("org.buddiesofbudgie.budgie-desktop.raven.widgets");
	_g_object_unref0 (self->priv->settings);
	self->priv->settings = _tmp12_;
	_tmp13_ = self->priv->settings;
	_tmp14_ = self->priv->check_confirm;
	g_settings_bind (_tmp13_, "confirm-widget-removal", (GObject*) _tmp14_, "active", G_SETTINGS_BIND_DEFAULT | G_SETTINGS_BIND_INVERT_BOOLEAN);
	_tmp15_ = self->priv->check_confirm;
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp15_, 6);
	_tmp16_ = self->priv->check_confirm;
	gtk_box_pack_end (content, (GtkWidget*) _tmp16_, FALSE, FALSE, (guint) 0);
	gtk_widget_show_all ((GtkWidget*) content);
	_tmp17_ = gtk_dialog_add_button ((GtkDialog*) self, _ ("Remove"), (gint) GTK_RESPONSE_ACCEPT);
	_tmp18_ = gtk_widget_get_style_context (_tmp17_);
	gtk_style_context_add_class (_tmp18_, GTK_STYLE_CLASS_DESTRUCTIVE_ACTION);
	_tmp19_ = gtk_dialog_add_button ((GtkDialog*) self, _ ("Cancel"), (gint) GTK_RESPONSE_CANCEL);
	_tmp20_ = gtk_widget_get_style_context (_tmp19_);
	gtk_style_context_add_class (_tmp20_, GTK_STYLE_CLASS_SUGGESTED_ACTION);
	_g_object_unref0 (sep);
	_g_object_unref0 (box);
	return self;
}

BudgieRemoveRavenWidgetDialog*
budgie_remove_raven_widget_dialog_new (GtkWindow* parent)
{
	return budgie_remove_raven_widget_dialog_construct (BUDGIE_TYPE_REMOVE_RAVEN_WIDGET_DIALOG, parent);
}

/**
* Simple wrapper to ensure dialog always does the right thing
*/
gboolean
budgie_remove_raven_widget_dialog_run (BudgieRemoveRavenWidgetDialog* self)
{
	GSettings* _tmp0_;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->settings;
	if (!g_settings_get_boolean (_tmp0_, "confirm-widget-removal")) {
		result = TRUE;
		return result;
	}
	result = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog)) == ((gint) GTK_RESPONSE_ACCEPT);
	return result;
}

static void
budgie_remove_raven_widget_dialog_class_init (BudgieRemoveRavenWidgetDialogClass * klass,
                                              gpointer klass_data)
{
	budgie_remove_raven_widget_dialog_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &BudgieRemoveRavenWidgetDialog_private_offset);
	G_OBJECT_CLASS (klass)->finalize = budgie_remove_raven_widget_dialog_finalize;
}

static void
budgie_remove_raven_widget_dialog_instance_init (BudgieRemoveRavenWidgetDialog * self,
                                                 gpointer klass)
{
	self->priv = budgie_remove_raven_widget_dialog_get_instance_private (self);
}

static void
budgie_remove_raven_widget_dialog_finalize (GObject * obj)
{
	BudgieRemoveRavenWidgetDialog * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BUDGIE_TYPE_REMOVE_RAVEN_WIDGET_DIALOG, BudgieRemoveRavenWidgetDialog);
	_g_object_unref0 (self->priv->settings);
	_g_object_unref0 (self->priv->check_confirm);
	_g_object_unref0 (self->priv->confirm_label);
	_g_object_unref0 (self->priv->confirm_image);
	G_OBJECT_CLASS (budgie_remove_raven_widget_dialog_parent_class)->finalize (obj);
}

/**
* RemoveRavenWidgetDialog is used to confirm whether the raven widget should *really* be
* removed
*/
static GType
budgie_remove_raven_widget_dialog_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BudgieRemoveRavenWidgetDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) budgie_remove_raven_widget_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BudgieRemoveRavenWidgetDialog), 0, (GInstanceInitFunc) budgie_remove_raven_widget_dialog_instance_init, NULL };
	GType budgie_remove_raven_widget_dialog_type_id;
	budgie_remove_raven_widget_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "BudgieRemoveRavenWidgetDialog", &g_define_type_info, 0);
	BudgieRemoveRavenWidgetDialog_private_offset = g_type_add_instance_private (budgie_remove_raven_widget_dialog_type_id, sizeof (BudgieRemoveRavenWidgetDialogPrivate));
	return budgie_remove_raven_widget_dialog_type_id;
}

GType
budgie_remove_raven_widget_dialog_get_type (void)
{
	static volatile gsize budgie_remove_raven_widget_dialog_type_id__once = 0;
	if (g_once_init_enter (&budgie_remove_raven_widget_dialog_type_id__once)) {
		GType budgie_remove_raven_widget_dialog_type_id;
		budgie_remove_raven_widget_dialog_type_id = budgie_remove_raven_widget_dialog_get_type_once ();
		g_once_init_leave (&budgie_remove_raven_widget_dialog_type_id__once, budgie_remove_raven_widget_dialog_type_id);
	}
	return budgie_remove_raven_widget_dialog_type_id__once;
}

