
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "gvc-enum-types.h"
#include "gvc-channel-map.h"
#include "gvc-mixer-card.h"
#include "gvc-mixer-control.h"
#include "gvc-mixer-event-role.h"
#include "gvc-mixer-sink.h"
#include "gvc-mixer-sink-input.h"
#include "gvc-mixer-source.h"
#include "gvc-mixer-source-output.h"
#include "gvc-mixer-stream.h"
#include "gvc-mixer-ui-device.h"

#define C_ENUM(v) ((gint) v)
#define C_FLAGS(v) ((guint) v)

/* enumerations from "gvc-mixer-control.h" */

GType
gvc_mixer_control_state_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (GVC_STATE_CLOSED), "GVC_STATE_CLOSED", "closed" },
        { C_ENUM (GVC_STATE_READY), "GVC_STATE_READY", "ready" },
        { C_ENUM (GVC_STATE_CONNECTING), "GVC_STATE_CONNECTING", "connecting" },
        { C_ENUM (GVC_STATE_FAILED), "GVC_STATE_FAILED", "failed" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("GvcMixerControlState"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

GType
gvc_headset_port_choice_get_type (void)
{
    static gsize gtype_id = 0;
    static const GFlagsValue values[] = {
        { C_FLAGS (GVC_HEADSET_PORT_CHOICE_NONE), "GVC_HEADSET_PORT_CHOICE_NONE", "none" },
        { C_FLAGS (GVC_HEADSET_PORT_CHOICE_HEADPHONES), "GVC_HEADSET_PORT_CHOICE_HEADPHONES", "headphones" },
        { C_FLAGS (GVC_HEADSET_PORT_CHOICE_HEADSET), "GVC_HEADSET_PORT_CHOICE_HEADSET", "headset" },
        { C_FLAGS (GVC_HEADSET_PORT_CHOICE_MIC), "GVC_HEADSET_PORT_CHOICE_MIC", "mic" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_flags_register_static (g_intern_static_string ("GvcHeadsetPortChoice"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "gvc-mixer-stream.h" */

GType
gvc_mixer_stream_state_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (GVC_STREAM_STATE_INVALID), "GVC_STREAM_STATE_INVALID", "invalid" },
        { C_ENUM (GVC_STREAM_STATE_RUNNING), "GVC_STREAM_STATE_RUNNING", "running" },
        { C_ENUM (GVC_STREAM_STATE_IDLE), "GVC_STREAM_STATE_IDLE", "idle" },
        { C_ENUM (GVC_STREAM_STATE_SUSPENDED), "GVC_STREAM_STATE_SUSPENDED", "suspended" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("GvcMixerStreamState"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* enumerations from "gvc-mixer-ui-device.h" */

GType
gvc_mixer_ui_device_direction_get_type (void)
{
    static gsize gtype_id = 0;
    static const GEnumValue values[] = {
        { C_ENUM (UIDeviceInput), "UIDeviceInput", "input" },
        { C_ENUM (UIDeviceOutput), "UIDeviceOutput", "output" },
        { 0, NULL, NULL }
    };
    if (g_once_init_enter (&gtype_id)) {
        GType new_type = g_enum_register_static (g_intern_static_string ("GvcMixerUIDeviceDirection"), values);
        g_once_init_leave (&gtype_id, new_type);
    }
    return (GType) gtype_id;
}

/* Generated data ends here */

