/* main.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from main.vala, do not modify */

/*
 * This file is part of budgie-desktop
 *
 * Copyright Budgie Desktop Developers
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <locale.h>
#include <glib/gi18n-lib.h>
#include <budgie-config.h>
#include <gtk/gtk.h>
#include <glib-object.h>
#include <gio/gio.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define BUDGIE_TYPE_POWER_APPLICATION (budgie_power_application_get_type ())
#define BUDGIE_POWER_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BUDGIE_TYPE_POWER_APPLICATION, BudgiePowerApplication))
#define BUDGIE_POWER_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BUDGIE_TYPE_POWER_APPLICATION, BudgiePowerApplicationClass))
#define BUDGIE_IS_POWER_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BUDGIE_TYPE_POWER_APPLICATION))
#define BUDGIE_IS_POWER_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BUDGIE_TYPE_POWER_APPLICATION))
#define BUDGIE_POWER_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BUDGIE_TYPE_POWER_APPLICATION, BudgiePowerApplicationClass))

typedef struct _BudgiePowerApplication BudgiePowerApplication;
typedef struct _BudgiePowerApplicationClass BudgiePowerApplicationClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

static gint budgie_main (gchar** args,
                  gint args_length1);
VALA_EXTERN GType budgie_power_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgiePowerApplication, g_object_unref)
VALA_EXTERN BudgiePowerApplication* budgie_power_application_new (void);
VALA_EXTERN BudgiePowerApplication* budgie_power_application_construct (GType object_type);

static gint
budgie_main (gchar** args,
             gint args_length1)
{
	BudgiePowerApplication* power_app = NULL;
	BudgiePowerApplication* _tmp0_;
	gint result;
	setlocale (LC_ALL, "");
	bindtextdomain (BUDGIE_GETTEXT_PACKAGE, BUDGIE_LOCALEDIR);
	bind_textdomain_codeset (BUDGIE_GETTEXT_PACKAGE, "UTF-8");
	textdomain (BUDGIE_GETTEXT_PACKAGE);
	_tmp0_ = budgie_power_application_new ();
	power_app = _tmp0_;
	result = g_application_run ((GApplication*) power_app, (gint) 0, NULL);
	_g_object_unref0 (power_app);
	return result;
}

int
main (int argc,
      char ** argv)
{
	return budgie_main (argv, argc);
}

