/* spacerapplet.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __SRC_PANEL_APPLETS_SPACER_SPACERAPPLET_H__
#define __SRC_PANEL_APPLETS_SPACER_SPACERAPPLET_H__

#include <libpeas.h>
#include "plugin.h"
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_SPACER_PLUGIN (spacer_plugin_get_type ())
#define SPACER_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SPACER_PLUGIN, SpacerPlugin))
#define SPACER_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SPACER_PLUGIN, SpacerPluginClass))
#define IS_SPACER_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SPACER_PLUGIN))
#define IS_SPACER_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SPACER_PLUGIN))
#define SPACER_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SPACER_PLUGIN, SpacerPluginClass))

typedef struct _SpacerPlugin SpacerPlugin;
typedef struct _SpacerPluginClass SpacerPluginClass;
typedef struct _SpacerPluginPrivate SpacerPluginPrivate;

#define TYPE_SPACER_SETTINGS (spacer_settings_get_type ())
#define SPACER_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SPACER_SETTINGS, SpacerSettings))
#define SPACER_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SPACER_SETTINGS, SpacerSettingsClass))
#define IS_SPACER_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SPACER_SETTINGS))
#define IS_SPACER_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SPACER_SETTINGS))
#define SPACER_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SPACER_SETTINGS, SpacerSettingsClass))

typedef struct _SpacerSettings SpacerSettings;
typedef struct _SpacerSettingsClass SpacerSettingsClass;
typedef struct _SpacerSettingsPrivate SpacerSettingsPrivate;

#define TYPE_SPACER_APPLET (spacer_applet_get_type ())
#define SPACER_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SPACER_APPLET, SpacerApplet))
#define SPACER_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SPACER_APPLET, SpacerAppletClass))
#define IS_SPACER_APPLET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SPACER_APPLET))
#define IS_SPACER_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SPACER_APPLET))
#define SPACER_APPLET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SPACER_APPLET, SpacerAppletClass))

typedef struct _SpacerApplet SpacerApplet;
typedef struct _SpacerAppletClass SpacerAppletClass;
typedef struct _SpacerAppletPrivate SpacerAppletPrivate;

struct _SpacerPlugin {
	PeasExtensionBase parent_instance;
	SpacerPluginPrivate * priv;
};

struct _SpacerPluginClass {
	PeasExtensionBaseClass parent_class;
};

struct _SpacerSettings {
	GtkGrid parent_instance;
	SpacerSettingsPrivate * priv;
};

struct _SpacerSettingsClass {
	GtkGridClass parent_class;
};

struct _SpacerApplet {
	BudgieApplet parent_instance;
	SpacerAppletPrivate * priv;
};

struct _SpacerAppletClass {
	BudgieAppletClass parent_class;
};

GType spacer_plugin_register_type (GTypeModule * module);
VALA_EXTERN GType spacer_plugin_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpacerPlugin, g_object_unref)
VALA_EXTERN SpacerPlugin* spacer_plugin_new (void);
VALA_EXTERN SpacerPlugin* spacer_plugin_construct (GType object_type);
GType spacer_settings_register_type (GTypeModule * module);
VALA_EXTERN GType spacer_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpacerSettings, g_object_unref)
VALA_EXTERN SpacerSettings* spacer_settings_new (GSettings* settings);
VALA_EXTERN SpacerSettings* spacer_settings_construct (GType object_type,
                                           GSettings* settings);
GType spacer_applet_register_type (GTypeModule * module);
VALA_EXTERN GType spacer_applet_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpacerApplet, g_object_unref)
VALA_EXTERN SpacerApplet* spacer_applet_new (const gchar* uuid);
VALA_EXTERN SpacerApplet* spacer_applet_construct (GType object_type,
                                       const gchar* uuid);
VALA_EXTERN gint spacer_applet_get_space_size (SpacerApplet* self);
VALA_EXTERN void spacer_applet_set_space_size (SpacerApplet* self,
                                   gint value);
VALA_EXTERN const gchar* spacer_applet_get_uuid (SpacerApplet* self);
VALA_EXTERN void spacer_applet_set_uuid (SpacerApplet* self,
                             const gchar* value);
VALA_EXTERN void peas_register_types (GTypeModule* module);

G_END_DECLS

#endif
