/* separatorapplet.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __SRC_PANEL_APPLETS_SEPARATOR_SEPARATORAPPLET_H__
#define __SRC_PANEL_APPLETS_SEPARATOR_SEPARATORAPPLET_H__

#include <libpeas.h>
#include "plugin.h"
#include <glib-object.h>
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_SEPARATOR_PLUGIN (separator_plugin_get_type ())
#define SEPARATOR_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SEPARATOR_PLUGIN, SeparatorPlugin))
#define SEPARATOR_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SEPARATOR_PLUGIN, SeparatorPluginClass))
#define IS_SEPARATOR_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SEPARATOR_PLUGIN))
#define IS_SEPARATOR_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SEPARATOR_PLUGIN))
#define SEPARATOR_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SEPARATOR_PLUGIN, SeparatorPluginClass))

typedef struct _SeparatorPlugin SeparatorPlugin;
typedef struct _SeparatorPluginClass SeparatorPluginClass;
typedef struct _SeparatorPluginPrivate SeparatorPluginPrivate;

#define TYPE_SEPARATOR_APPLET (separator_applet_get_type ())
#define SEPARATOR_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SEPARATOR_APPLET, SeparatorApplet))
#define SEPARATOR_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SEPARATOR_APPLET, SeparatorAppletClass))
#define IS_SEPARATOR_APPLET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SEPARATOR_APPLET))
#define IS_SEPARATOR_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SEPARATOR_APPLET))
#define SEPARATOR_APPLET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SEPARATOR_APPLET, SeparatorAppletClass))

typedef struct _SeparatorApplet SeparatorApplet;
typedef struct _SeparatorAppletClass SeparatorAppletClass;
typedef struct _SeparatorAppletPrivate SeparatorAppletPrivate;

struct _SeparatorPlugin {
	PeasExtensionBase parent_instance;
	SeparatorPluginPrivate * priv;
};

struct _SeparatorPluginClass {
	PeasExtensionBaseClass parent_class;
};

struct _SeparatorApplet {
	BudgieApplet parent_instance;
	SeparatorAppletPrivate * priv;
};

struct _SeparatorAppletClass {
	BudgieAppletClass parent_class;
};

GType separator_plugin_register_type (GTypeModule * module);
VALA_EXTERN GType separator_plugin_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeparatorPlugin, g_object_unref)
VALA_EXTERN SeparatorPlugin* separator_plugin_new (void);
VALA_EXTERN SeparatorPlugin* separator_plugin_construct (GType object_type);
GType separator_applet_register_type (GTypeModule * module);
VALA_EXTERN GType separator_applet_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeparatorApplet, g_object_unref)
VALA_EXTERN SeparatorApplet* separator_applet_new (void);
VALA_EXTERN SeparatorApplet* separator_applet_construct (GType object_type);
VALA_EXTERN void peas_register_types (GTypeModule* module);

G_END_DECLS

#endif
