/* org.buddiesofbudgie.budgie-desktop.raven.widget.Calendar.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __SRC_RAVEN_WIDGETS_CALENDAR_ORG_BUDDIESOFBUDGIE_BUDGIE_DESKTOP_RAVEN_WIDGET_CALENDAR_H__
#define __SRC_RAVEN_WIDGETS_CALENDAR_ORG_BUDDIESOFBUDGIE_BUDGIE_DESKTOP_RAVEN_WIDGET_CALENDAR_H__

#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <libpeas.h>
#include "raven-plugin.h"
#include <gtk/gtk.h>

G_BEGIN_DECLS

#define RAVEN_DBUS_NAME "org.budgie_desktop.Raven"
#define RAVEN_DBUS_OBJECT_PATH "/org/budgie_desktop/Raven"
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_RAVEN_TO_CALENDAR_REMOTE (raven_to_calendar_remote_get_type ())
#define RAVEN_TO_CALENDAR_REMOTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_RAVEN_TO_CALENDAR_REMOTE, RavenToCalendarRemote))
#define IS_RAVEN_TO_CALENDAR_REMOTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_RAVEN_TO_CALENDAR_REMOTE))
#define RAVEN_TO_CALENDAR_REMOTE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_RAVEN_TO_CALENDAR_REMOTE, RavenToCalendarRemoteIface))

typedef struct _RavenToCalendarRemote RavenToCalendarRemote;
typedef struct _RavenToCalendarRemoteIface RavenToCalendarRemoteIface;

#define TYPE_RAVEN_TO_CALENDAR_REMOTE_PROXY (raven_to_calendar_remote_proxy_get_type ())

#define TYPE_CALENDAR_RAVEN_PLUGIN (calendar_raven_plugin_get_type ())
#define CALENDAR_RAVEN_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CALENDAR_RAVEN_PLUGIN, CalendarRavenPlugin))
#define CALENDAR_RAVEN_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CALENDAR_RAVEN_PLUGIN, CalendarRavenPluginClass))
#define IS_CALENDAR_RAVEN_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CALENDAR_RAVEN_PLUGIN))
#define IS_CALENDAR_RAVEN_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CALENDAR_RAVEN_PLUGIN))
#define CALENDAR_RAVEN_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CALENDAR_RAVEN_PLUGIN, CalendarRavenPluginClass))

typedef struct _CalendarRavenPlugin CalendarRavenPlugin;
typedef struct _CalendarRavenPluginClass CalendarRavenPluginClass;
typedef struct _CalendarRavenPluginPrivate CalendarRavenPluginPrivate;

#define TYPE_CALENDAR_RAVEN_WIDGET (calendar_raven_widget_get_type ())
#define CALENDAR_RAVEN_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CALENDAR_RAVEN_WIDGET, CalendarRavenWidget))
#define CALENDAR_RAVEN_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CALENDAR_RAVEN_WIDGET, CalendarRavenWidgetClass))
#define IS_CALENDAR_RAVEN_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CALENDAR_RAVEN_WIDGET))
#define IS_CALENDAR_RAVEN_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CALENDAR_RAVEN_WIDGET))
#define CALENDAR_RAVEN_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CALENDAR_RAVEN_WIDGET, CalendarRavenWidgetClass))

typedef struct _CalendarRavenWidget CalendarRavenWidget;
typedef struct _CalendarRavenWidgetClass CalendarRavenWidgetClass;
typedef struct _CalendarRavenWidgetPrivate CalendarRavenWidgetPrivate;

#define TYPE_CALENDAR_RAVEN_WIDGET_SETTINGS (calendar_raven_widget_settings_get_type ())
#define CALENDAR_RAVEN_WIDGET_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CALENDAR_RAVEN_WIDGET_SETTINGS, CalendarRavenWidgetSettings))
#define CALENDAR_RAVEN_WIDGET_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CALENDAR_RAVEN_WIDGET_SETTINGS, CalendarRavenWidgetSettingsClass))
#define IS_CALENDAR_RAVEN_WIDGET_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CALENDAR_RAVEN_WIDGET_SETTINGS))
#define IS_CALENDAR_RAVEN_WIDGET_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CALENDAR_RAVEN_WIDGET_SETTINGS))
#define CALENDAR_RAVEN_WIDGET_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CALENDAR_RAVEN_WIDGET_SETTINGS, CalendarRavenWidgetSettingsClass))

typedef struct _CalendarRavenWidgetSettings CalendarRavenWidgetSettings;
typedef struct _CalendarRavenWidgetSettingsClass CalendarRavenWidgetSettingsClass;
typedef struct _CalendarRavenWidgetSettingsPrivate CalendarRavenWidgetSettingsPrivate;

struct _RavenToCalendarRemoteIface {
	GTypeInterface parent_iface;
};

struct _CalendarRavenPlugin {
	PeasExtensionBase parent_instance;
	CalendarRavenPluginPrivate * priv;
};

struct _CalendarRavenPluginClass {
	PeasExtensionBaseClass parent_class;
};

struct _CalendarRavenWidget {
	BudgieRavenWidget parent_instance;
	CalendarRavenWidgetPrivate * priv;
};

struct _CalendarRavenWidgetClass {
	BudgieRavenWidgetClass parent_class;
};

struct _CalendarRavenWidgetSettings {
	GtkGrid parent_instance;
	CalendarRavenWidgetSettingsPrivate * priv;
};

struct _CalendarRavenWidgetSettingsClass {
	GtkGridClass parent_class;
};

GType raven_to_calendar_remote_register_type (GTypeModule * module);
VALA_EXTERN GType raven_to_calendar_remote_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (RavenToCalendarRemote, g_object_unref)
VALA_EXTERN GType raven_to_calendar_remote_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void raven_to_calendar_remote_proxy_register_dynamic_type (GTypeModule* module);
VALA_EXTERN guint raven_to_calendar_remote_register_object (void* object,
                                                GDBusConnection* connection,
                                                const gchar* path,
                                                GError** error);
GType calendar_raven_plugin_register_type (GTypeModule * module);
VALA_EXTERN GType calendar_raven_plugin_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CalendarRavenPlugin, g_object_unref)
VALA_EXTERN CalendarRavenPlugin* calendar_raven_plugin_new (void);
VALA_EXTERN CalendarRavenPlugin* calendar_raven_plugin_construct (GType object_type);
GType calendar_raven_widget_register_type (GTypeModule * module);
VALA_EXTERN GType calendar_raven_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CalendarRavenWidget, g_object_unref)
VALA_EXTERN CalendarRavenWidget* calendar_raven_widget_new (const gchar* uuid,
                                                GSettings* settings);
VALA_EXTERN CalendarRavenWidget* calendar_raven_widget_construct (GType object_type,
                                                      const gchar* uuid,
                                                      GSettings* settings);
GType calendar_raven_widget_settings_register_type (GTypeModule * module);
VALA_EXTERN GType calendar_raven_widget_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CalendarRavenWidgetSettings, g_object_unref)
VALA_EXTERN CalendarRavenWidgetSettings* calendar_raven_widget_settings_new (GSettings* settings);
VALA_EXTERN CalendarRavenWidgetSettings* calendar_raven_widget_settings_construct (GType object_type,
                                                                       GSettings* settings);
VALA_EXTERN void peas_register_types (GTypeModule* module);

G_END_DECLS

#endif
