/* settings_raven.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from settings_raven.vala, do not modify */

/*
 * This file is part of budgie-desktop
 *
 * Copyright Budgie Desktop Developers
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#include <gtk/gtk.h>
#include <glib-object.h>
#include "budgie-private.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <glib/gi18n-lib.h>

#define BUDGIE_SETTINGS_GROUP_APPEARANCE "appearance"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define BUDGIE_TYPE_SETTINGS_PAGE (budgie_settings_page_get_type ())
#define BUDGIE_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BUDGIE_TYPE_SETTINGS_PAGE, BudgieSettingsPage))
#define BUDGIE_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BUDGIE_TYPE_SETTINGS_PAGE, BudgieSettingsPageClass))
#define BUDGIE_IS_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BUDGIE_TYPE_SETTINGS_PAGE))
#define BUDGIE_IS_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BUDGIE_TYPE_SETTINGS_PAGE))
#define BUDGIE_SETTINGS_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BUDGIE_TYPE_SETTINGS_PAGE, BudgieSettingsPageClass))

typedef struct _BudgieSettingsPage BudgieSettingsPage;
typedef struct _BudgieSettingsPageClass BudgieSettingsPageClass;
typedef struct _BudgieSettingsPagePrivate BudgieSettingsPagePrivate;

#define BUDGIE_TYPE_RAVEN_PAGE (budgie_raven_page_get_type ())
#define BUDGIE_RAVEN_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BUDGIE_TYPE_RAVEN_PAGE, BudgieRavenPage))
#define BUDGIE_RAVEN_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BUDGIE_TYPE_RAVEN_PAGE, BudgieRavenPageClass))
#define BUDGIE_IS_RAVEN_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BUDGIE_TYPE_RAVEN_PAGE))
#define BUDGIE_IS_RAVEN_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BUDGIE_TYPE_RAVEN_PAGE))
#define BUDGIE_RAVEN_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BUDGIE_TYPE_RAVEN_PAGE, BudgieRavenPageClass))

typedef struct _BudgieRavenPage BudgieRavenPage;
typedef struct _BudgieRavenPageClass BudgieRavenPageClass;
typedef struct _BudgieRavenPagePrivate BudgieRavenPagePrivate;
enum  {
	BUDGIE_RAVEN_PAGE_0_PROPERTY,
	BUDGIE_RAVEN_PAGE_NUM_PROPERTIES
};
static GParamSpec* budgie_raven_page_properties[BUDGIE_RAVEN_PAGE_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BUDGIE_TYPE_RAVEN_WIDGETS_PAGE (budgie_raven_widgets_page_get_type ())
#define BUDGIE_RAVEN_WIDGETS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BUDGIE_TYPE_RAVEN_WIDGETS_PAGE, BudgieRavenWidgetsPage))
#define BUDGIE_RAVEN_WIDGETS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BUDGIE_TYPE_RAVEN_WIDGETS_PAGE, BudgieRavenWidgetsPageClass))
#define BUDGIE_IS_RAVEN_WIDGETS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BUDGIE_TYPE_RAVEN_WIDGETS_PAGE))
#define BUDGIE_IS_RAVEN_WIDGETS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BUDGIE_TYPE_RAVEN_WIDGETS_PAGE))
#define BUDGIE_RAVEN_WIDGETS_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BUDGIE_TYPE_RAVEN_WIDGETS_PAGE, BudgieRavenWidgetsPageClass))

typedef struct _BudgieRavenWidgetsPage BudgieRavenWidgetsPage;
typedef struct _BudgieRavenWidgetsPageClass BudgieRavenWidgetsPageClass;

#define BUDGIE_TYPE_SETTINGS_GRID (budgie_settings_grid_get_type ())
#define BUDGIE_SETTINGS_GRID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BUDGIE_TYPE_SETTINGS_GRID, BudgieSettingsGrid))
#define BUDGIE_SETTINGS_GRID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BUDGIE_TYPE_SETTINGS_GRID, BudgieSettingsGridClass))
#define BUDGIE_IS_SETTINGS_GRID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BUDGIE_TYPE_SETTINGS_GRID))
#define BUDGIE_IS_SETTINGS_GRID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BUDGIE_TYPE_SETTINGS_GRID))
#define BUDGIE_SETTINGS_GRID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BUDGIE_TYPE_SETTINGS_GRID, BudgieSettingsGridClass))

typedef struct _BudgieSettingsGrid BudgieSettingsGrid;
typedef struct _BudgieSettingsGridClass BudgieSettingsGridClass;

#define BUDGIE_TYPE_RAVEN_SETTINGS_PAGE (budgie_raven_settings_page_get_type ())
#define BUDGIE_RAVEN_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BUDGIE_TYPE_RAVEN_SETTINGS_PAGE, BudgieRavenSettingsPage))
#define BUDGIE_RAVEN_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BUDGIE_TYPE_RAVEN_SETTINGS_PAGE, BudgieRavenSettingsPageClass))
#define BUDGIE_IS_RAVEN_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BUDGIE_TYPE_RAVEN_SETTINGS_PAGE))
#define BUDGIE_IS_RAVEN_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BUDGIE_TYPE_RAVEN_SETTINGS_PAGE))
#define BUDGIE_RAVEN_SETTINGS_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BUDGIE_TYPE_RAVEN_SETTINGS_PAGE, BudgieRavenSettingsPageClass))

typedef struct _BudgieRavenSettingsPage BudgieRavenSettingsPage;
typedef struct _BudgieRavenSettingsPageClass BudgieRavenSettingsPageClass;

struct _BudgieSettingsPage {
	GtkBox parent_instance;
	BudgieSettingsPagePrivate * priv;
};

struct _BudgieSettingsPageClass {
	GtkBoxClass parent_class;
};

struct _BudgieRavenPage {
	BudgieSettingsPage parent_instance;
	BudgieRavenPagePrivate * priv;
};

struct _BudgieRavenPageClass {
	BudgieSettingsPageClass parent_class;
};

struct _BudgieRavenPagePrivate {
	GtkStack* stack;
	GtkStackSwitcher* switcher;
};

static gint BudgieRavenPage_private_offset;
static gpointer budgie_raven_page_parent_class = NULL;

VALA_EXTERN GType budgie_settings_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieSettingsPage, g_object_unref)
VALA_EXTERN GType budgie_raven_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieRavenPage, g_object_unref)
VALA_EXTERN BudgieRavenPage* budgie_raven_page_new (BudgieDesktopManager* manager);
VALA_EXTERN BudgieRavenPage* budgie_raven_page_construct (GType object_type,
                                              BudgieDesktopManager* manager);
VALA_EXTERN BudgieRavenWidgetsPage* budgie_raven_widgets_page_new (BudgieDesktopManager* manager);
VALA_EXTERN BudgieRavenWidgetsPage* budgie_raven_widgets_page_construct (GType object_type,
                                                             BudgieDesktopManager* manager);
VALA_EXTERN GType budgie_raven_widgets_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieRavenWidgetsPage, g_object_unref)
VALA_EXTERN BudgieRavenSettingsPage* budgie_raven_settings_page_new (void);
VALA_EXTERN BudgieRavenSettingsPage* budgie_raven_settings_page_construct (GType object_type);
VALA_EXTERN GType budgie_settings_grid_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieSettingsGrid, g_object_unref)
VALA_EXTERN GType budgie_raven_settings_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieRavenSettingsPage, g_object_unref)
static void budgie_raven_page_finalize (GObject * obj);
static GType budgie_raven_page_get_type_once (void);

static inline gpointer
budgie_raven_page_get_instance_private (BudgieRavenPage* self)
{
	return G_STRUCT_MEMBER_P (self, BudgieRavenPage_private_offset);
}

BudgieRavenPage*
budgie_raven_page_construct (GType object_type,
                             BudgieDesktopManager* manager)
{
	BudgieRavenPage * self = NULL;
	GtkBox* swbox = NULL;
	GtkBox* _tmp0_;
	GtkStackSwitcher* _tmp1_;
	GtkStackSwitcher* _tmp2_;
	GtkStack* _tmp3_;
	GtkStack* _tmp4_;
	GtkStack* _tmp5_;
	GtkStack* _tmp6_;
	GtkStackSwitcher* _tmp7_;
	GtkStack* _tmp8_;
	GtkStackSwitcher* _tmp9_;
	GtkStack* _tmp10_;
	GtkStack* _tmp11_;
	BudgieRavenWidgetsPage* _tmp12_;
	BudgieRavenWidgetsPage* _tmp13_;
	GtkStack* _tmp14_;
	BudgieRavenSettingsPage* _tmp15_;
	BudgieRavenSettingsPage* _tmp16_;
	self = (BudgieRavenPage*) g_object_new (object_type, "group", BUDGIE_SETTINGS_GROUP_APPEARANCE, "content-id", "raven", "title", "Raven", "display-weight", 3, "icon-name", "preferences-calendar-and-tasks", NULL);
	gtk_container_set_border_width ((GtkContainer*) self, (guint) 0);
	gtk_widget_set_margin_top ((GtkWidget*) self, 8);
	gtk_widget_set_margin_bottom ((GtkWidget*) self, 8);
	gtk_widget_set_halign ((GtkWidget*) self, GTK_ALIGN_FILL);
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
	g_object_ref_sink (_tmp0_);
	swbox = _tmp0_;
	gtk_box_pack_start ((GtkBox*) self, (GtkWidget*) swbox, FALSE, FALSE, (guint) 0);
	_tmp1_ = (GtkStackSwitcher*) gtk_stack_switcher_new ();
	g_object_ref_sink (_tmp1_);
	_g_object_unref0 (self->priv->switcher);
	self->priv->switcher = _tmp1_;
	_tmp2_ = self->priv->switcher;
	gtk_widget_set_halign ((GtkWidget*) _tmp2_, GTK_ALIGN_CENTER);
	_tmp3_ = (GtkStack*) gtk_stack_new ();
	g_object_ref_sink (_tmp3_);
	_g_object_unref0 (self->priv->stack);
	self->priv->stack = _tmp3_;
	_tmp4_ = self->priv->stack;
	gtk_widget_set_margin_top ((GtkWidget*) _tmp4_, 12);
	_tmp5_ = self->priv->stack;
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp5_, 12);
	_tmp6_ = self->priv->stack;
	gtk_stack_set_homogeneous (_tmp6_, FALSE);
	_tmp7_ = self->priv->switcher;
	_tmp8_ = self->priv->stack;
	gtk_stack_switcher_set_stack (_tmp7_, _tmp8_);
	_tmp9_ = self->priv->switcher;
	gtk_box_pack_start (swbox, (GtkWidget*) _tmp9_, TRUE, TRUE, (guint) 0);
	_tmp10_ = self->priv->stack;
	gtk_box_pack_start ((GtkBox*) self, (GtkWidget*) _tmp10_, TRUE, TRUE, (guint) 0);
	_tmp11_ = self->priv->stack;
	_tmp12_ = budgie_raven_widgets_page_new (manager);
	g_object_ref_sink (_tmp12_);
	_tmp13_ = _tmp12_;
	gtk_stack_add_titled (_tmp11_, (GtkWidget*) _tmp13_, "widgets", _ ("Widgets"));
	_g_object_unref0 (_tmp13_);
	_tmp14_ = self->priv->stack;
	_tmp15_ = budgie_raven_settings_page_new ();
	g_object_ref_sink (_tmp15_);
	_tmp16_ = _tmp15_;
	gtk_stack_add_titled (_tmp14_, (GtkWidget*) _tmp16_, "settings", _ ("Settings"));
	_g_object_unref0 (_tmp16_);
	gtk_widget_show_all ((GtkWidget*) self);
	_g_object_unref0 (swbox);
	return self;
}

BudgieRavenPage*
budgie_raven_page_new (BudgieDesktopManager* manager)
{
	return budgie_raven_page_construct (BUDGIE_TYPE_RAVEN_PAGE, manager);
}

static void
budgie_raven_page_class_init (BudgieRavenPageClass * klass,
                              gpointer klass_data)
{
	budgie_raven_page_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &BudgieRavenPage_private_offset);
	G_OBJECT_CLASS (klass)->finalize = budgie_raven_page_finalize;
}

static void
budgie_raven_page_instance_init (BudgieRavenPage * self,
                                 gpointer klass)
{
	self->priv = budgie_raven_page_get_instance_private (self);
}

static void
budgie_raven_page_finalize (GObject * obj)
{
	BudgieRavenPage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BUDGIE_TYPE_RAVEN_PAGE, BudgieRavenPage);
	_g_object_unref0 (self->priv->stack);
	_g_object_unref0 (self->priv->switcher);
	G_OBJECT_CLASS (budgie_raven_page_parent_class)->finalize (obj);
}

/**
* RavenPage shows options for configuring Raven
*/
static GType
budgie_raven_page_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BudgieRavenPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) budgie_raven_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BudgieRavenPage), 0, (GInstanceInitFunc) budgie_raven_page_instance_init, NULL };
	GType budgie_raven_page_type_id;
	budgie_raven_page_type_id = g_type_register_static (BUDGIE_TYPE_SETTINGS_PAGE, "BudgieRavenPage", &g_define_type_info, 0);
	BudgieRavenPage_private_offset = g_type_add_instance_private (budgie_raven_page_type_id, sizeof (BudgieRavenPagePrivate));
	return budgie_raven_page_type_id;
}

GType
budgie_raven_page_get_type (void)
{
	static volatile gsize budgie_raven_page_type_id__once = 0;
	if (g_once_init_enter (&budgie_raven_page_type_id__once)) {
		GType budgie_raven_page_type_id;
		budgie_raven_page_type_id = budgie_raven_page_get_type_once ();
		g_once_init_leave (&budgie_raven_page_type_id__once, budgie_raven_page_type_id);
	}
	return budgie_raven_page_type_id__once;
}

