/* lockkeysapplet.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __SRC_PANEL_APPLETS_LOCK_KEYS_LOCKKEYSAPPLET_H__
#define __SRC_PANEL_APPLETS_LOCK_KEYS_LOCKKEYSAPPLET_H__

#include <libpeas.h>
#include "plugin.h"
#include <glib-object.h>
#include <gdk/gdk.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_LOCK_KEYS_PLUGIN (lock_keys_plugin_get_type ())
#define LOCK_KEYS_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LOCK_KEYS_PLUGIN, LockKeysPlugin))
#define LOCK_KEYS_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LOCK_KEYS_PLUGIN, LockKeysPluginClass))
#define IS_LOCK_KEYS_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LOCK_KEYS_PLUGIN))
#define IS_LOCK_KEYS_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LOCK_KEYS_PLUGIN))
#define LOCK_KEYS_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LOCK_KEYS_PLUGIN, LockKeysPluginClass))

typedef struct _LockKeysPlugin LockKeysPlugin;
typedef struct _LockKeysPluginClass LockKeysPluginClass;
typedef struct _LockKeysPluginPrivate LockKeysPluginPrivate;

#define TYPE_LOCK_KEYS_APPLET (lock_keys_applet_get_type ())
#define LOCK_KEYS_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LOCK_KEYS_APPLET, LockKeysApplet))
#define LOCK_KEYS_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LOCK_KEYS_APPLET, LockKeysAppletClass))
#define IS_LOCK_KEYS_APPLET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LOCK_KEYS_APPLET))
#define IS_LOCK_KEYS_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LOCK_KEYS_APPLET))
#define LOCK_KEYS_APPLET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LOCK_KEYS_APPLET, LockKeysAppletClass))

typedef struct _LockKeysApplet LockKeysApplet;
typedef struct _LockKeysAppletClass LockKeysAppletClass;
typedef struct _LockKeysAppletPrivate LockKeysAppletPrivate;

struct _LockKeysPlugin {
	PeasExtensionBase parent_instance;
	LockKeysPluginPrivate * priv;
};

struct _LockKeysPluginClass {
	PeasExtensionBaseClass parent_class;
};

struct _LockKeysApplet {
	BudgieApplet parent_instance;
	LockKeysAppletPrivate * priv;
};

struct _LockKeysAppletClass {
	BudgieAppletClass parent_class;
};

GType lock_keys_plugin_register_type (GTypeModule * module);
VALA_EXTERN GType lock_keys_plugin_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LockKeysPlugin, g_object_unref)
VALA_EXTERN LockKeysPlugin* lock_keys_plugin_new (void);
VALA_EXTERN LockKeysPlugin* lock_keys_plugin_construct (GType object_type);
GType lock_keys_applet_register_type (GTypeModule * module);
VALA_EXTERN GType lock_keys_applet_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LockKeysApplet, g_object_unref)
VALA_EXTERN LockKeysApplet* lock_keys_applet_new (void);
VALA_EXTERN LockKeysApplet* lock_keys_applet_construct (GType object_type);
VALA_EXTERN void lock_keys_applet_toggle_caps (LockKeysApplet* self);
VALA_EXTERN void lock_keys_applet_toggle_num (LockKeysApplet* self);
VALA_EXTERN gboolean lock_keys_applet_on_panel_widget_clicked (LockKeysApplet* self,
                                                   GdkEventButton* eventbutton,
                                                   const gchar* button);
VALA_EXTERN void lock_keys_applet_on_state_changed (LockKeysApplet* self);
VALA_EXTERN void peas_register_types (GTypeModule* module);

G_END_DECLS

#endif
