/* userindicator.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __SRC_PANEL_APPLETS_USER_INDICATOR_USERINDICATOR_H__
#define __SRC_PANEL_APPLETS_USER_INDICATOR_USERINDICATOR_H__

#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <libpeas.h>
#include "plugin.h"
#include <glib-object.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define USER_SYMBOLIC_ICON "system-shutdown-symbolic"

#define TYPE_USER_INDICATOR (user_indicator_get_type ())
#define USER_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_USER_INDICATOR, UserIndicator))
#define USER_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_USER_INDICATOR, UserIndicatorClass))
#define IS_USER_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_USER_INDICATOR))
#define IS_USER_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_USER_INDICATOR))
#define USER_INDICATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_USER_INDICATOR, UserIndicatorClass))

typedef struct _UserIndicator UserIndicator;
typedef struct _UserIndicatorClass UserIndicatorClass;
typedef struct _UserIndicatorPrivate UserIndicatorPrivate;

#define TYPE_USER_INDICATOR_APPLET (user_indicator_applet_get_type ())
#define USER_INDICATOR_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_USER_INDICATOR_APPLET, UserIndicatorApplet))
#define USER_INDICATOR_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_USER_INDICATOR_APPLET, UserIndicatorAppletClass))
#define IS_USER_INDICATOR_APPLET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_USER_INDICATOR_APPLET))
#define IS_USER_INDICATOR_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_USER_INDICATOR_APPLET))
#define USER_INDICATOR_APPLET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_USER_INDICATOR_APPLET, UserIndicatorAppletClass))

typedef struct _UserIndicatorApplet UserIndicatorApplet;
typedef struct _UserIndicatorAppletClass UserIndicatorAppletClass;
typedef struct _UserIndicatorAppletPrivate UserIndicatorAppletPrivate;

struct _UserIndicator {
	PeasExtensionBase parent_instance;
	UserIndicatorPrivate * priv;
};

struct _UserIndicatorClass {
	PeasExtensionBaseClass parent_class;
};

struct _UserIndicatorApplet {
	BudgieApplet parent_instance;
	UserIndicatorAppletPrivate * priv;
};

struct _UserIndicatorAppletClass {
	BudgieAppletClass parent_class;
};

GType user_indicator_register_type (GTypeModule * module);
VALA_EXTERN GType user_indicator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (UserIndicator, g_object_unref)
VALA_EXTERN UserIndicator* user_indicator_new (void);
VALA_EXTERN UserIndicator* user_indicator_construct (GType object_type);
GType user_indicator_applet_register_type (GTypeModule * module);
VALA_EXTERN GType user_indicator_applet_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (UserIndicatorApplet, g_object_unref)
VALA_EXTERN UserIndicatorApplet* user_indicator_applet_new (const gchar* uuid);
VALA_EXTERN UserIndicatorApplet* user_indicator_applet_construct (GType object_type,
                                                      const gchar* uuid);
VALA_EXTERN const gchar* user_indicator_applet_get_uuid (UserIndicatorApplet* self);
VALA_EXTERN void user_indicator_applet_set_uuid (UserIndicatorApplet* self,
                                     const gchar* value);
VALA_EXTERN void peas_register_types (GTypeModule* module);

G_END_DECLS

#endif
