
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */


#pragma once

#include <glib-object.h>

#include "applet.h"
#include "popover.h"

G_BEGIN_DECLS

/* enumerations from "/build/budgie-desktop/src/build/../budgie-desktop/src/plugin/panel/applet.h" */
GType budgie_panel_action_get_type (void) G_GNUC_CONST;
#define BUDGIE_TYPE_PANEL_ACTION (budgie_panel_action_get_type ())
GType budgie_panel_position_get_type (void) G_GNUC_CONST;
#define BUDGIE_TYPE_PANEL_POSITION (budgie_panel_position_get_type ())
G_END_DECLS

/* Generated data ends here */

