/* placesindicator.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __SRC_PANEL_APPLETS_PLACES_INDICATOR_PLACESINDICATOR_H__
#define __SRC_PANEL_APPLETS_PLACES_INDICATOR_PLACESINDICATOR_H__

#include <libpeas.h>
#include "plugin.h"
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_PLACES_INDICATOR (places_indicator_get_type ())
#define PLACES_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PLACES_INDICATOR, PlacesIndicator))
#define PLACES_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PLACES_INDICATOR, PlacesIndicatorClass))
#define IS_PLACES_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PLACES_INDICATOR))
#define IS_PLACES_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PLACES_INDICATOR))
#define PLACES_INDICATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PLACES_INDICATOR, PlacesIndicatorClass))

typedef struct _PlacesIndicator PlacesIndicator;
typedef struct _PlacesIndicatorClass PlacesIndicatorClass;
typedef struct _PlacesIndicatorPrivate PlacesIndicatorPrivate;

#define TYPE_PLACES_INDICATOR_SETTINGS (places_indicator_settings_get_type ())
#define PLACES_INDICATOR_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PLACES_INDICATOR_SETTINGS, PlacesIndicatorSettings))
#define PLACES_INDICATOR_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PLACES_INDICATOR_SETTINGS, PlacesIndicatorSettingsClass))
#define IS_PLACES_INDICATOR_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PLACES_INDICATOR_SETTINGS))
#define IS_PLACES_INDICATOR_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PLACES_INDICATOR_SETTINGS))
#define PLACES_INDICATOR_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PLACES_INDICATOR_SETTINGS, PlacesIndicatorSettingsClass))

typedef struct _PlacesIndicatorSettings PlacesIndicatorSettings;
typedef struct _PlacesIndicatorSettingsClass PlacesIndicatorSettingsClass;
typedef struct _PlacesIndicatorSettingsPrivate PlacesIndicatorSettingsPrivate;

#define TYPE_PLACES_INDICATOR_APPLET (places_indicator_applet_get_type ())
#define PLACES_INDICATOR_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PLACES_INDICATOR_APPLET, PlacesIndicatorApplet))
#define PLACES_INDICATOR_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PLACES_INDICATOR_APPLET, PlacesIndicatorAppletClass))
#define IS_PLACES_INDICATOR_APPLET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PLACES_INDICATOR_APPLET))
#define IS_PLACES_INDICATOR_APPLET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PLACES_INDICATOR_APPLET))
#define PLACES_INDICATOR_APPLET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PLACES_INDICATOR_APPLET, PlacesIndicatorAppletClass))

typedef struct _PlacesIndicatorApplet PlacesIndicatorApplet;
typedef struct _PlacesIndicatorAppletClass PlacesIndicatorAppletClass;
typedef struct _PlacesIndicatorAppletPrivate PlacesIndicatorAppletPrivate;

#define TYPE_PLACES_INDICATOR_WINDOW (places_indicator_window_get_type ())
#define PLACES_INDICATOR_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PLACES_INDICATOR_WINDOW, PlacesIndicatorWindow))
#define PLACES_INDICATOR_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PLACES_INDICATOR_WINDOW, PlacesIndicatorWindowClass))
#define IS_PLACES_INDICATOR_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PLACES_INDICATOR_WINDOW))
#define IS_PLACES_INDICATOR_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PLACES_INDICATOR_WINDOW))
#define PLACES_INDICATOR_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PLACES_INDICATOR_WINDOW, PlacesIndicatorWindowClass))

typedef struct _PlacesIndicatorWindow PlacesIndicatorWindow;
typedef struct _PlacesIndicatorWindowClass PlacesIndicatorWindowClass;
typedef struct _PlacesIndicatorWindowPrivate PlacesIndicatorWindowPrivate;

#define TYPE_MESSAGE_REVEALER (message_revealer_get_type ())
#define MESSAGE_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MESSAGE_REVEALER, MessageRevealer))
#define MESSAGE_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MESSAGE_REVEALER, MessageRevealerClass))
#define IS_MESSAGE_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MESSAGE_REVEALER))
#define IS_MESSAGE_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MESSAGE_REVEALER))
#define MESSAGE_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MESSAGE_REVEALER, MessageRevealerClass))

typedef struct _MessageRevealer MessageRevealer;
typedef struct _MessageRevealerClass MessageRevealerClass;
typedef struct _MessageRevealerPrivate MessageRevealerPrivate;

#define TYPE_PLACES_SECTION (places_section_get_type ())
#define PLACES_SECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PLACES_SECTION, PlacesSection))
#define PLACES_SECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PLACES_SECTION, PlacesSectionClass))
#define IS_PLACES_SECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PLACES_SECTION))
#define IS_PLACES_SECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PLACES_SECTION))
#define PLACES_SECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PLACES_SECTION, PlacesSectionClass))

typedef struct _PlacesSection PlacesSection;
typedef struct _PlacesSectionClass PlacesSectionClass;
typedef struct _PlacesSectionPrivate PlacesSectionPrivate;

#define TYPE_LIST_ITEM (list_item_get_type ())
#define LIST_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIST_ITEM, ListItem))
#define LIST_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIST_ITEM, ListItemClass))
#define IS_LIST_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIST_ITEM))
#define IS_LIST_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIST_ITEM))
#define LIST_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIST_ITEM, ListItemClass))

typedef struct _ListItem ListItem;
typedef struct _ListItemClass ListItemClass;

#define TYPE_PLACE_ITEM (place_item_get_type ())
#define PLACE_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PLACE_ITEM, PlaceItem))
#define PLACE_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PLACE_ITEM, PlaceItemClass))
#define IS_PLACE_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PLACE_ITEM))
#define IS_PLACE_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PLACE_ITEM))
#define PLACE_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PLACE_ITEM, PlaceItemClass))

typedef struct _PlaceItem PlaceItem;
typedef struct _PlaceItemClass PlaceItemClass;
typedef struct _ListItemPrivate ListItemPrivate;

#define TYPE_VOLUME_ITEM (volume_item_get_type ())
#define VOLUME_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VOLUME_ITEM, VolumeItem))
#define VOLUME_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VOLUME_ITEM, VolumeItemClass))
#define IS_VOLUME_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VOLUME_ITEM))
#define IS_VOLUME_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VOLUME_ITEM))
#define VOLUME_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VOLUME_ITEM, VolumeItemClass))

typedef struct _VolumeItem VolumeItem;
typedef struct _VolumeItemClass VolumeItemClass;
typedef struct _VolumeItemPrivate VolumeItemPrivate;

#define TYPE_MOUNT_ITEM (mount_item_get_type ())
#define MOUNT_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MOUNT_ITEM, MountItem))
#define MOUNT_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MOUNT_ITEM, MountItemClass))
#define IS_MOUNT_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MOUNT_ITEM))
#define IS_MOUNT_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MOUNT_ITEM))
#define MOUNT_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MOUNT_ITEM, MountItemClass))

typedef struct _MountItem MountItem;
typedef struct _MountItemClass MountItemClass;
typedef struct _MountItemPrivate MountItemPrivate;
typedef struct _PlaceItemPrivate PlaceItemPrivate;

#define TYPE_MOUNT_HELPER (mount_helper_get_type ())
#define MOUNT_HELPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MOUNT_HELPER, MountHelper))
#define MOUNT_HELPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MOUNT_HELPER, MountHelperClass))
#define IS_MOUNT_HELPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MOUNT_HELPER))
#define IS_MOUNT_HELPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MOUNT_HELPER))
#define MOUNT_HELPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MOUNT_HELPER, MountHelperClass))

typedef struct _MountHelper MountHelper;
typedef struct _MountHelperClass MountHelperClass;
typedef struct _MountHelperPrivate MountHelperPrivate;

struct _PlacesIndicator {
	PeasExtensionBase parent_instance;
	PlacesIndicatorPrivate * priv;
};

struct _PlacesIndicatorClass {
	PeasExtensionBaseClass parent_class;
};

struct _PlacesIndicatorSettings {
	GtkGrid parent_instance;
	PlacesIndicatorSettingsPrivate * priv;
};

struct _PlacesIndicatorSettingsClass {
	GtkGridClass parent_class;
};

struct _PlacesIndicatorApplet {
	BudgieApplet parent_instance;
	PlacesIndicatorAppletPrivate * priv;
};

struct _PlacesIndicatorAppletClass {
	BudgieAppletClass parent_class;
};

struct _PlacesIndicatorWindow {
	BudgiePopover parent_instance;
	PlacesIndicatorWindowPrivate * priv;
};

struct _PlacesIndicatorWindowClass {
	BudgiePopoverClass parent_class;
};

struct _MessageRevealer {
	GtkRevealer parent_instance;
	MessageRevealerPrivate * priv;
};

struct _MessageRevealerClass {
	GtkRevealerClass parent_class;
};

struct _PlacesSection {
	GtkBox parent_instance;
	PlacesSectionPrivate * priv;
};

struct _PlacesSectionClass {
	GtkBoxClass parent_class;
};

struct _ListItem {
	GtkBox parent_instance;
	ListItemPrivate * priv;
	gchar* item_class;
	gchar* category_name;
	GtkToolButton* name_button;
	GtkOverlay* overlay;
	GtkSpinner* spin;
};

struct _ListItemClass {
	GtkBoxClass parent_class;
	void (*cancel_operation) (ListItem* self);
};

struct _VolumeItem {
	ListItem parent_instance;
	VolumeItemPrivate * priv;
};

struct _VolumeItemClass {
	ListItemClass parent_class;
};

struct _MountItem {
	ListItem parent_instance;
	MountItemPrivate * priv;
};

struct _MountItemClass {
	ListItemClass parent_class;
};

struct _PlaceItem {
	ListItem parent_instance;
	PlaceItemPrivate * priv;
};

struct _PlaceItemClass {
	ListItemClass parent_class;
};

struct _MountHelper {
	GMountOperation parent_instance;
	MountHelperPrivate * priv;
};

struct _MountHelperClass {
	GMountOperationClass parent_class;
};

GType places_indicator_register_type (GTypeModule * module);
VALA_EXTERN GType places_indicator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PlacesIndicator, g_object_unref)
VALA_EXTERN PlacesIndicator* places_indicator_new (void);
VALA_EXTERN PlacesIndicator* places_indicator_construct (GType object_type);
GType places_indicator_settings_register_type (GTypeModule * module);
VALA_EXTERN GType places_indicator_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PlacesIndicatorSettings, g_object_unref)
VALA_EXTERN PlacesIndicatorSettings* places_indicator_settings_new (GSettings* settings);
VALA_EXTERN PlacesIndicatorSettings* places_indicator_settings_construct (GType object_type,
                                                              GSettings* settings);
GType places_indicator_applet_register_type (GTypeModule * module);
VALA_EXTERN GType places_indicator_applet_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PlacesIndicatorApplet, g_object_unref)
VALA_EXTERN PlacesIndicatorApplet* places_indicator_applet_new (const gchar* uuid);
VALA_EXTERN PlacesIndicatorApplet* places_indicator_applet_construct (GType object_type,
                                                          const gchar* uuid);
VALA_EXTERN void places_indicator_applet_toggle_popover (PlacesIndicatorApplet* self);
VALA_EXTERN void places_indicator_applet_on_settings_changed (PlacesIndicatorApplet* self,
                                                  const gchar* key);
VALA_EXTERN const gchar* places_indicator_applet_get_uuid (PlacesIndicatorApplet* self);
VALA_EXTERN void places_indicator_applet_set_uuid (PlacesIndicatorApplet* self,
                                       const gchar* value);
VALA_EXTERN void peas_register_types (GTypeModule* module);
GType places_indicator_window_register_type (GTypeModule * module);
VALA_EXTERN GType places_indicator_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PlacesIndicatorWindow, g_object_unref)
VALA_EXTERN PlacesIndicatorWindow* places_indicator_window_new (GtkWidget* window_parent);
VALA_EXTERN PlacesIndicatorWindow* places_indicator_window_construct (GType object_type,
                                                          GtkWidget* window_parent);
VALA_EXTERN gboolean places_indicator_window_get_expand_places (PlacesIndicatorWindow* self);
VALA_EXTERN void places_indicator_window_set_expand_places (PlacesIndicatorWindow* self,
                                                gboolean value);
VALA_EXTERN gboolean places_indicator_window_get_show_places (PlacesIndicatorWindow* self);
VALA_EXTERN void places_indicator_window_set_show_places (PlacesIndicatorWindow* self,
                                              gboolean value);
VALA_EXTERN gboolean places_indicator_window_get_show_drives (PlacesIndicatorWindow* self);
VALA_EXTERN void places_indicator_window_set_show_drives (PlacesIndicatorWindow* self,
                                              gboolean value);
VALA_EXTERN gboolean places_indicator_window_get_show_networks (PlacesIndicatorWindow* self);
VALA_EXTERN void places_indicator_window_set_show_networks (PlacesIndicatorWindow* self,
                                                gboolean value);
GType message_revealer_register_type (GTypeModule * module);
VALA_EXTERN GType message_revealer_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MessageRevealer, g_object_unref)
VALA_EXTERN MessageRevealer* message_revealer_new (void);
VALA_EXTERN MessageRevealer* message_revealer_construct (GType object_type);
VALA_EXTERN gboolean message_revealer_hide_it (MessageRevealer* self);
VALA_EXTERN void message_revealer_set_content (MessageRevealer* self,
                                   const gchar* message);
GType places_section_register_type (GTypeModule * module);
VALA_EXTERN GType places_section_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PlacesSection, g_object_unref)
VALA_EXTERN PlacesSection* places_section_new (void);
VALA_EXTERN PlacesSection* places_section_construct (GType object_type);
VALA_EXTERN void places_section_contract_revealer (PlacesSection* self,
                                       gboolean animate);
VALA_EXTERN void places_section_clear (PlacesSection* self);
GType list_item_register_type (GTypeModule * module);
VALA_EXTERN GType list_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ListItem, g_object_unref)
GType place_item_register_type (GTypeModule * module);
VALA_EXTERN GType place_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PlaceItem, g_object_unref)
VALA_EXTERN void places_section_add_item (PlacesSection* self,
                              PlaceItem* item);
VALA_EXTERN void places_section_reveal (PlacesSection* self,
                            gboolean state);
VALA_EXTERN void places_section_show_alternative_header (PlacesSection* self,
                                             gboolean state);
VALA_EXTERN gboolean places_section_is_revealed (PlacesSection* self);
VALA_EXTERN ListItem* list_item_construct (GType object_type);
VALA_EXTERN void list_item_set_button (ListItem* self,
                           const gchar* label,
                           GtkImage* image,
                           gboolean spinner,
                           gboolean offset_spinner);
VALA_EXTERN GtkImage* list_item_get_icon (ListItem* self,
                              GIcon* icon);
VALA_EXTERN gchar* list_item_get_item_category (ListItem* self);
VALA_EXTERN void list_item_open_directory (ListItem* self,
                               GFile* root);
VALA_EXTERN void list_item_cancel_operation (ListItem* self);
GType volume_item_register_type (GTypeModule * module);
VALA_EXTERN GType volume_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (VolumeItem, g_object_unref)
VALA_EXTERN VolumeItem* volume_item_new (GVolume* volume);
VALA_EXTERN VolumeItem* volume_item_construct (GType object_type,
                                   GVolume* volume);
GType mount_item_register_type (GTypeModule * module);
VALA_EXTERN GType mount_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MountItem, g_object_unref)
VALA_EXTERN MountItem* mount_item_new (GMount* mount,
                           const gchar* class);
VALA_EXTERN MountItem* mount_item_construct (GType object_type,
                                 GMount* mount,
                                 const gchar* class);
VALA_EXTERN PlaceItem* place_item_new (GFile* file,
                           const gchar* class,
                           const gchar* bookmark_name);
VALA_EXTERN PlaceItem* place_item_construct (GType object_type,
                                 GFile* file,
                                 const gchar* class,
                                 const gchar* bookmark_name);
GType mount_helper_register_type (GTypeModule * module);
VALA_EXTERN GType mount_helper_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MountHelper, g_object_unref)
VALA_EXTERN MountHelper* mount_helper_new (void);
VALA_EXTERN MountHelper* mount_helper_construct (GType object_type);
VALA_EXTERN GtkRevealer* mount_helper_get_encryption_form (MountHelper* self);
VALA_EXTERN GtkEntry* mount_helper_get_password_entry (MountHelper* self);

G_END_DECLS

#endif
